#!/usr/bin/python3
"""
    GeckoLogStruct - A class to manage the LogStruct for 'InYJ v54'
"""

from . import (
    GeckoByteStructAccessor,
    GeckoWordStructAccessor,
    GeckoTimeStructAccessor,
    GeckoBoolStructAccessor,
    GeckoEnumStructAccessor,
    GeckoTempStructAccessor,
)

# Constants for this class
ACCPQI = "".join(
    chr(c)
    for c in [70, 105, 108, 116, 83, 117, 115, 112, 101, 110, 100, 66, 121, 85, 68]
)
ACQFFT = "".join(chr(c) for c in [80, 97, 99, 107, 67, 111, 114, 101, 82, 101, 118])
AFIKJP = "".join(chr(c) for c in [67, 70, 71, 53])
AHEOCT = 308
AJVDQL = "".join(chr(c) for c in [80, 97, 99, 107, 88, 101, 80, 50, 50, 66, 76])
AKQXPI = "".join(chr(c) for c in [72, 73])
AKSTSE = 466
AMJMAO = "".join(
    chr(c)
    for c in [
        83,
        108,
        97,
        118,
        101,
        84,
        104,
        101,
        114,
        109,
        105,
        115,
        116,
        97,
        110,
        99,
        101,
        69,
        114,
        114,
    ]
)
AOAWBS = "".join(
    chr(c) for c in [82, 104, 70, 108, 111, 68, 101, 116, 101, 99, 116, 101, 100]
)
AONPYY = 266
ASSAKQ = "".join(chr(c) for c in [85, 100, 80, 49])
ATDZXN = "".join(chr(c) for c in [67, 70, 71, 49, 49])
AWBSIR = "".join(
    chr(c) for c in [82, 104, 82, 101, 103, 80, 114, 111, 98, 101, 69, 114, 114]
)
BDJQRJ = "".join(chr(c) for c in [75, 56, 53])
BFEGZU = 310
BHZVOA = 477
BIAMJM = "".join(
    chr(c)
    for c in [83, 108, 97, 118, 101, 82, 101, 103, 79, 118, 101, 114, 72, 101, 97, 116]
)
BJEUTO = "".join(chr(c) for c in [80, 49, 72])
BLKXSJ = "".join(chr(c) for c in [83, 119, 109, 65, 100, 99])
BMJVHF = 256
BQFYLJ = "".join(
    chr(c)
    for c in [83, 108, 97, 118, 101, 70, 108, 111, 68, 101, 116, 101, 99, 116, 101, 100]
)
BQNRXC = 448
BQSNQL = "".join(chr(c) for c in [105, 110, 88, 77])
BSIRYX = "".join(
    chr(c) for c in [82, 104, 72, 114, 75, 105, 110, 78, 111, 70, 108, 111]
)
BSKSOK = "".join(chr(c) for c in [85, 100, 81, 117, 105, 101, 116, 84, 105, 109, 101])
BSSUHB = "".join(chr(c) for c in [80, 97, 99, 107, 67, 111, 110, 102, 82, 101, 118])
BVWVUB = 301
BWJYKL = "".join(
    chr(c) for c in [84, 104, 101, 114, 109, 70, 117, 115, 101, 69, 114, 114]
)
BXIBHZ = "".join(chr(c) for c in [67, 70, 71, 50, 56])
BXYBQS = "".join(chr(c) for c in [77, 73, 65])
CBFEGZ = "".join(chr(c) for c in [76, 111, 99, 107, 77, 111, 100, 101])
CCPQIP = "".join(
    chr(c)
    for c in [
        70,
        105,
        108,
        116,
        83,
        117,
        115,
        112,
        101,
        110,
        100,
        101,
        100,
        66,
        121,
        79,
        84,
    ]
)
CGETIX = "".join(chr(c) for c in [67, 70, 71, 50, 50])
CHWDAF = "".join(chr(c) for c in [67, 70, 71, 51])
CMCVDS = "".join(chr(c) for c in [76, 73])
CPQIPO = "".join(
    chr(c)
    for c in [
        70,
        105,
        108,
        116,
        83,
        117,
        115,
        112,
        101,
        110,
        100,
        101,
        100,
        66,
        121,
        69,
        114,
        114,
    ]
)
CQBMJV = 317
CQFFTT = 293
CRTFMN = 358
CTHBSK = 303
CVYYPI = "".join(chr(c) for c in [83, 116, 105, 99, 107, 66, 97, 110, 107])
CWAONP = 264
CXQIEF = "".join(chr(c) for c in [85, 100, 80, 51])
DAFIKJ = 452
DGKEAK = 464
DJQRJJ = "".join(chr(c) for c in [75, 56])
DNIBXT = "".join(
    chr(c) for c in [80, 97, 99, 107, 70, 117, 115, 101, 49, 82, 97, 116, 105, 110, 103]
)
DNQGVU = 326
DQLAII = "".join(
    chr(c) for c in [80, 97, 99, 107, 88, 101, 79, 117, 116, 112, 117, 116, 115]
)
DSBDJQ = "".join(chr(c) for c in [75, 50, 48, 48])
DSSRUR = 256
DUBSSU = "".join(chr(c) for c in [80, 97, 99, 107, 67, 111, 110, 102, 73, 68])
DZXNQT = "".join(chr(c) for c in [67, 70, 71, 49, 50])
EAKSTS = "".join(chr(c) for c in [67, 70, 71, 49, 56])
ECVYYP = "".join(
    chr(c) for c in [67, 111, 110, 102, 105, 103, 83, 101, 108, 101, 99, 116]
)
EFJTAC = 272
EFXQGL = 258
EGZUQE = "".join(chr(c) for c in [80, 65, 82, 84, 73, 65, 76])
EJNIBX = 289
EKVKZI = "".join(chr(c) for c in [49, 54, 75])
ELHBQN = "".join(chr(c) for c in [83, 68, 105, 114, 101, 99, 116, 67, 117, 114])
EMCGET = "".join(chr(c) for c in [67, 70, 71, 50, 49])
EOCTHB = 307
ETIXQV = "".join(chr(c) for c in [67, 70, 71, 50, 51])
EUTOPH = "".join(chr(c) for c in [80, 50, 72])
EXLSXU = "".join(chr(c) for c in [73, 78, 84, 69, 82, 78, 65, 76])
FCRTFM = "".join(chr(c) for c in [75, 101, 121, 112, 97, 100, 73, 68])
FEFJTA = "".join(
    chr(c)
    for c in [
        82,
        101,
        109,
        111,
        116,
        101,
        66,
        114,
        101,
        97,
        107,
        101,
        114,
        73,
        110,
        100,
        101,
        120,
    ]
)
FEGZUQ = "".join(chr(c) for c in [85, 78, 76, 79, 67, 75])
FFTTID = 294
FIKJPU = 453
FJBIAM = "".join(
    chr(c)
    for c in [83, 108, 97, 118, 101, 75, 105, 110, 80, 117, 109, 112, 79, 102, 102]
)
FJTACC = "".join(chr(c) for c in [67, 108, 101, 97, 110])
FMNHTB = "".join(chr(c) for c in [75, 101, 121, 112, 97, 100, 82, 101, 108])
FTHECV = "".join(
    chr(c) for c in [73, 110, 115, 116, 97, 108, 108, 101, 114, 79, 112, 116]
)
FTSIFJ = 350
FTTIDU = "".join(
    chr(c) for c in [80, 97, 99, 107, 67, 111, 110, 102, 105, 103, 76, 105, 98]
)
FWRKIN = 285
FYLJUI = "".join(
    chr(c)
    for c in [83, 108, 97, 118, 101, 75, 105, 110, 78, 111, 70, 108, 111, 69, 114, 114]
)
FZDGKE = 463
GDSBDJ = 357
GETIXQ = 470
GKEAKS = "".join(chr(c) for c in [67, 70, 71, 49, 55])
GQPLSP = "".join(chr(c) for c in [80, 49, 72, 83, 116, 117, 99, 107])
GSELHB = 325
GTYIYW = "".join(chr(c) for c in [70, 117, 108, 108, 79, 110])
GVUNXN = "".join(chr(c) for c in [83, 79, 117, 116, 49, 67, 117, 114])
GYOUSP = 280
GZUQEX = "".join(chr(c) for c in [70, 85, 76, 76])
HBQNRX = "".join(chr(c) for c in [67, 70, 71, 48])
HBSKSO = 362
HBVWVU = "".join(
    chr(c)
    for c in [80, 97, 99, 107, 78, 117, 109, 98, 101, 114, 79, 102, 67, 111, 110, 102]
)
HBXIBH = 475
HECVYY = "".join(
    chr(c) for c in [65, 99, 99, 101, 115, 115, 111, 114, 121, 79, 112, 116]
)
HEOCTH = "".join(chr(c) for c in [85, 100, 76, 105])
HFTHEC = "".join(chr(c) for c in [])
HIUSOO = "".join(chr(c) for c in [80, 52])
HTBJEU = 320
HUGTYI = "".join(chr(c) for c in [80, 52, 76])
HUOJRJ = 261
HWDAFI = 451
HXEKVK = "".join(chr(c) for c in [80, 97, 99, 107, 77, 101, 109, 82, 97, 110, 103, 101])
HZVOAC = "".join(chr(c) for c in [67, 70, 71, 51, 48])
IACQFF = 291
IAMJMA = "".join(
    chr(c)
    for c in [
        83,
        108,
        97,
        118,
        101,
        84,
        104,
        101,
        114,
        109,
        70,
        117,
        115,
        101,
        69,
        114,
        114,
    ]
)
IBHZVO = "".join(chr(c) for c in [67, 70, 71, 50, 57])
IBXTIA = "".join(chr(c) for c in [51, 48, 65])
IBXYBQ = "".join(chr(c) for c in [77, 97, 115, 73, 66, 67])
ICXQIE = 2
IDNIBX = "".join(chr(c) for c in [80, 97, 99, 107, 78, 111, 73, 110, 70, 108, 111])
IDUBSS = 296
IEFXQG = "".join(chr(c) for c in [85, 100, 80, 53])
IFJBIA = "".join(
    chr(c)
    for c in [83, 108, 97, 118, 101, 82, 101, 108, 97, 121, 83, 116, 117, 99, 107]
)
IGYOUS = "".join(chr(c) for c in [67, 104, 101, 99, 107, 70, 108, 111])
IHBXIB = "".join(chr(c) for c in [67, 70, 71, 50, 55])
IIDNIB = "".join(
    chr(c)
    for c in [
        80,
        97,
        99,
        107,
        88,
        101,
        67,
        69,
        65,
        99,
        99,
        79,
        110,
        70,
        117,
        115,
        101,
        50,
    ]
)
IJUGSE = "".join(chr(c) for c in [83, 79, 117, 116, 72, 116, 114, 67, 117, 114])
IKFWRK = "".join(
    chr(c) for c in [83, 108, 97, 118, 101, 82, 101, 103, 83, 108, 111, 112, 101]
)
IKJPUN = "".join(chr(c) for c in [67, 70, 71, 54])
ILXWAJ = "".join(chr(c) for c in [80, 97, 99, 107, 82, 101, 103, 105, 111, 110])
INEJNI = 288
IPIVLA = "".join(chr(c) for c in [68, 82, 65, 73, 78])
IPOUYN = "".join(
    chr(c) for c in [83, 119, 109, 80, 117, 114, 103, 101, 83, 117, 115, 112]
)
IRYXBQ = "".join(
    chr(c) for c in [82, 104, 78, 111, 70, 108, 111, 88, 84, 114, 105, 101, 115]
)
IUSOOQ = "".join(chr(c) for c in [80, 53])
IUXFEF = 270
IVDNQG = 324
IVLASS = "".join(chr(c) for c in [79, 70, 70])
IXQVXO = "".join(chr(c) for c in [67, 70, 71, 50, 52])
IYWSKW = 321
JBIAMJ = 351
JEUTOP = "".join(chr(c) for c in [80, 49, 76])
JHIUSO = "".join(chr(c) for c in [80, 51])
JIGYOU = "".join(
    chr(c)
    for c in [69, 120, 116, 80, 114, 111, 98, 101, 68, 101, 116, 101, 99, 116, 101, 100]
)
JJJVYF = "".join(chr(c) for c in [75, 49, 48, 48])
JJVYFC = "".join(chr(c) for c in [75, 54, 48, 48, 72, 69])
JMAOAW = "".join(
    chr(c)
    for c in [83, 108, 97, 118, 101, 77, 105, 115, 115, 105, 110, 103, 69, 114, 114]
)
JMCBFE = 5
JNIBXY = "".join(chr(c) for c in [85, 110, 107, 110, 111, 119, 110])
JPUNRJ = "".join(chr(c) for c in [67, 70, 71, 55])
JQRJJJ = "".join(chr(c) for c in [75, 52])
JTACCP = 273
JUGSEL = 333
JUIKFW = "".join(chr(c) for c in [83, 108, 97, 118, 101, 72, 76, 69, 114, 114])
JUTYEK = "".join(chr(c) for c in [83, 84, 79, 80])
JVDQLA = "".join(chr(c) for c in [80, 50, 50])
JVHFTH = 319
JVYFCR = "".join(chr(c) for c in [75, 51, 48, 48])
JWMNZM = "".join(
    chr(c) for c in [68, 105, 115, 112, 108, 97, 121, 101, 100, 84, 101, 109, 112, 71]
)
JYKLGQ = "".join(
    chr(c) for c in [65, 109, 98, 105, 97, 110, 116, 79, 72, 76, 101, 118, 101, 108, 50]
)
JYMOUN = "".join(chr(c) for c in [77, 69, 68])
JZTATD = 457
KCWAON = "".join(
    chr(c) for c in [82, 101, 109, 111, 116, 101, 70, 105, 108, 116, 68, 117, 114]
)
KEAKST = 465
KFWRKI = "".join(chr(c) for c in [80, 97, 99, 107, 66, 111, 111, 116, 73, 68])
KINEJN = "".join(chr(c) for c in [80, 97, 99, 107, 66, 111, 111, 116, 82, 101, 108])
KJPUNR = 454
KLGQPL = 283
KMLOIJ = "".join(chr(c) for c in [83, 79, 117, 116, 52, 67, 117, 114])
KPHUOJ = 306
KSOKPH = "".join(chr(c) for c in [85, 100, 76, 105, 103, 104, 116, 84, 105, 109, 101])
KSTSEM = "".join(chr(c) for c in [67, 70, 71, 49, 57])
KVKZIL = "".join(chr(c) for c in [51, 50, 75])
KWIVDN = 323
KXSJWM = "".join(chr(c) for c in [79, 118, 101, 114, 84, 101, 109, 112])
KZILXW = "".join(chr(c) for c in [54, 52, 75])
LAIIDN = "".join(chr(c) for c in [51, 79, 80])
LASSAK = "".join(chr(c) for c in [65, 76, 76])
LGQPLS = "".join(chr(c) for c in [82, 101, 103, 79, 118, 101, 114, 72, 101, 97, 116])
LHBQNR = 332
LIUXFE = "".join(
    chr(c)
    for c in [
        82,
        101,
        109,
        111,
        116,
        101,
        67,
        111,
        110,
        102,
        105,
        103,
        73,
        110,
        100,
        101,
        120,
    ]
)
LJUIKF = "".join(
    chr(c) for c in [83, 108, 97, 118, 101, 78, 111, 70, 108, 111, 69, 114, 114]
)
LKXSJW = 355
LNMHXE = "".join(chr(c) for c in [75, 56, 48, 48])
LOIJUG = "".join(chr(c) for c in [83, 79, 117, 116, 53, 67, 117, 114])
LRAHEO = 1
LSPFTS = "".join(chr(c) for c in [72, 101, 97, 116, 101, 114, 83, 116, 117, 99, 107])
LXWAJV = "".join(chr(c) for c in [85, 76])
MAOAWB = 354
MCBFEG = "".join(chr(c) for c in [83, 76, 86, 95, 72, 69, 65, 84, 69, 82])
MCGETI = 469
MFZDGK = "".join(chr(c) for c in [67, 70, 71, 49, 53])
MJIGYO = 279
MJMAOA = "".join(
    chr(c)
    for c in [
        83,
        108,
        97,
        118,
        101,
        65,
        109,
        98,
        105,
        97,
        110,
        116,
        79,
        72,
        76,
        101,
        118,
        101,
        108,
        50,
    ]
)
MJVHFT = "".join(chr(c) for c in [77, 101, 110, 117])
MLOIJU = 330
MNHTBJ = 361
MNZMJI = "".join(chr(c) for c in [72, 101, 97, 116, 105, 110, 103])
NBLKXS = "".join(
    chr(c) for c in [83, 108, 97, 118, 101, 83, 119, 109, 65, 99, 116, 105, 118, 101]
)
NEJNIB = "".join(chr(c) for c in [80, 97, 99, 107, 84, 121, 112, 101])
NHTBJE = "".join(chr(c) for c in [83, 79, 117, 116, 49])
NIBXTI = "".join(chr(c) for c in [50, 53, 65])
NIBXYB = "".join(chr(c) for c in [105, 110, 88, 69])
NKMLOI = 329
NMHXEK = "".join(chr(c) for c in [105, 110, 89, 74])
NPYYLI = "".join(
    chr(c)
    for c in [82, 101, 109, 111, 116, 101, 69, 99, 111, 110, 65, 99, 116, 105, 111, 110]
)
NQGVUN = "".join(chr(c) for c in [72, 84, 82])
NQJYMO = 313
NQLNMH = "".join(chr(c) for c in [105, 110, 84, 111, 117, 99, 104])
NQTMFZ = 461
NRJZTA = 456
NRSJMC = 3
NRXCHW = 449
NXNKML = 328
OACMCV = 479
OAWBSI = "".join(chr(c) for c in [82, 104, 72, 119, 72, 76])
OCTHBS = "".join(chr(c) for c in [85, 100, 80, 117, 109, 112, 84, 105, 109, 101])
OIHBXI = 474
OIJUGS = 331
OJRJHI = "".join(chr(c) for c in [76, 79, 87])
OKPHUO = "".join(chr(c) for c in [85, 100, 76, 49, 50, 48, 84, 105, 109, 101])
ONPYYL = "".join(
    chr(c) for c in [69, 99, 111, 110, 111, 109, 121, 65, 99, 99, 101, 115, 115]
)
OOQNRS = "".join(chr(c) for c in [66, 76])
OPHUGT = "".join(chr(c) for c in [80, 51, 76])
OQNRSJ = "".join(chr(c) for c in [67, 80])
OUNBLK = "".join(
    chr(c) for c in [83, 108, 97, 118, 101, 83, 119, 109, 80, 117, 114, 103, 101]
)
OUSPBW = 281
OUYNQJ = "".join(chr(c) for c in [83, 119, 109, 80, 117, 114, 103, 101])
PBWJYK = 352
PFTSIF = "".join(
    chr(c) for c in [83, 108, 97, 118, 101, 80, 49, 72, 83, 116, 117, 99, 107]
)
PHUGTY = "".join(chr(c) for c in [80, 52, 72])
PHUOJR = "".join(chr(c) for c in [80, 49])
PICXQI = "".join(chr(c) for c in [85, 100, 80, 50])
PIPIVL = "".join(chr(c) for c in [78, 79, 84, 95, 83, 69, 84])
PIVLAS = "".join(chr(c) for c in [83, 79, 65, 75])
PLSPFT = "".join(chr(c) for c in [80, 50, 72, 83, 116, 117, 99, 107])
POUYNQ = 282
PQIPOU = "".join(chr(c) for c in [67, 80, 79, 84])
PUNRJZ = 455
PYYLIU = 267
QBMJVH = "".join(chr(c) for c in [72, 111, 117, 114, 115])
QEXLSX = 262
QFFTTI = "".join(chr(c) for c in [80, 97, 99, 107, 67, 111, 114, 101, 82, 101, 108])
QFYLJU = 314
QGLRAH = "".join(chr(c) for c in [79, 78])
QIEFXQ = 6
QIPOUY = 274
QJYMOU = "".join(chr(c) for c in [78, 79])
QLAIID = "".join(chr(c) for c in [53, 79, 80])
QLNMHX = "".join(chr(c) for c in [105, 110, 89, 84])
QNRSJM = "".join(chr(c) for c in [79, 51])
QNRXCH = "".join(chr(c) for c in [67, 70, 71, 49])
QPLSPF = 284
QRJJJV = "".join(chr(c) for c in [75, 53])
QSNQLN = "".join(chr(c) for c in [75, 54, 48, 48])
QTMFZD = "".join(chr(c) for c in [67, 70, 71, 49, 52])
QVXOIH = "".join(chr(c) for c in [67, 70, 71, 50, 53])
QXPICX = 0
RAHEOC = "".join(chr(c) for c in [85, 100, 76, 49, 50, 48])
RJHIUS = "".join(chr(c) for c in [80, 50])
RJJJVY = "".join(chr(c) for c in [75, 54, 48, 48, 76, 69])
RJZTAT = "".join(chr(c) for c in [67, 70, 71, 57])
RKINEJ = 287
RSJMCB = "".join(chr(c) for c in [76, 49, 50, 48])
RTFMNH = "".join(chr(c) for c in [75, 101, 121, 112, 97, 100, 82, 101, 118])
RXCHWD = "".join(chr(c) for c in [67, 70, 71, 50])
SAKQXP = "".join(chr(c) for c in [76, 79])
SBDJQR = "".join(chr(c) for c in [75, 52, 48, 48])
SEMCGE = 468
SIFJBI = "".join(
    chr(c) for c in [83, 108, 97, 118, 101, 72, 116, 114, 83, 116, 117, 99, 107]
)
SIRYXB = 309
SJMCBF = "".join(chr(c) for c in [77, 83, 84, 82, 95, 72, 69, 65, 84, 69, 82])
SJWMNZ = 275
SKSOKP = 304
SKWIVD = "".join(chr(c) for c in [83, 79, 117, 116, 52])
SNQLNM = "".join(chr(c) for c in [105, 110, 84, 101, 114, 102, 97, 99, 101])
SOKPHU = 305
SPBWJY = "".join(
    chr(c) for c in [83, 108, 97, 118, 101, 79, 118, 101, 114, 84, 101, 109, 112]
)
SPFTSI = "".join(chr(c) for c in [82, 101, 108, 97, 121, 83, 116, 117, 99, 107])
SSAKQX = 259
SSRURA = 479
SSUHBV = 299
STSEMC = 467
SUHBVW = "".join(chr(c) for c in [80, 97, 99, 107, 67, 111, 110, 102, 82, 101, 108])
SXUJUT = "".join(
    chr(c)
    for c in [
        82,
        101,
        109,
        111,
        116,
        101,
        70,
        105,
        108,
        116,
        65,
        99,
        116,
        105,
        111,
        110,
    ]
)
TACCPQ = "".join(chr(c) for c in [80, 117, 114, 103, 101])
TATDZX = 458
TBJEUT = "".join(chr(c) for c in [78, 65])
TDZXNQ = 459
TFMNHT = 360
THBSKS = "".join(chr(c) for c in [85, 100, 80, 49, 76, 84, 105, 109, 101])
THECVY = "".join(chr(c) for c in [68, 101, 97, 108, 101, 114, 79, 112, 116])
TIACQF = "".join(chr(c) for c in [80, 97, 99, 107, 67, 111, 114, 101, 73, 68])
TIDUBS = "".join(
    chr(c) for c in [80, 97, 99, 107, 83, 116, 97, 116, 117, 115, 76, 105, 98]
)
TIXQVX = 471
TMFZDG = 462
TOPHUG = "".join(chr(c) for c in [80, 51, 72])
TSEMCG = "".join(chr(c) for c in [67, 70, 71, 50, 48])
TSIFJB = "".join(
    chr(c) for c in [83, 108, 97, 118, 101, 80, 50, 72, 83, 116, 117, 99, 107]
)
TTIDUB = 295
TYEKCW = "".join(chr(c) for c in [78, 69, 87])
UBSSUH = 297
UBYGDS = "".join(chr(c) for c in [70, 117, 108, 108])
UGSELH = "".join(chr(c) for c in [83, 68, 105, 114, 101, 99, 116])
UGTYIY = "".join(chr(c) for c in [66, 76, 79])
UHBVWV = 300
UIKFWR = "".join(
    chr(c)
    for c in [83, 108, 97, 118, 101, 82, 101, 103, 80, 114, 111, 98, 101, 69, 114, 114]
)
UJUTYE = "".join(chr(c) for c in [73, 68, 76, 69])
UNBLKX = 353
UNRJZT = "".join(chr(c) for c in [67, 70, 71, 56])
UNXNKM = "".join(chr(c) for c in [83, 79, 117, 116, 50, 67, 117, 114])
UOJRJH = "".join(chr(c) for c in [72, 73, 71, 72])
UQEXLS = "".join(
    chr(c) for c in [70, 105, 108, 116, 101, 114, 65, 99, 99, 101, 115, 115]
)
USOOQN = 260
USPBWJ = "".join(chr(c) for c in [69, 99, 111, 110, 65, 99, 116, 105, 118, 101])
UTOPHU = "".join(chr(c) for c in [80, 50, 76])
UTYEKC = "".join(chr(c) for c in [83, 84, 65, 82, 84])
UXFEFJ = "".join(
    chr(c)
    for c in [82, 101, 109, 111, 116, 101, 78, 98, 79, 102, 80, 104, 97, 115, 101, 115]
)
UYNQJY = "".join(chr(c) for c in [83, 119, 109, 65, 99, 116, 105, 118, 101])
VDNQGV = "".join(chr(c) for c in [83, 79, 117, 116, 72, 116, 114])
VDSSRU = 54
VHFTHE = "".join(chr(c) for c in [78, 79, 82, 77, 65, 76])
VKZILX = "".join(chr(c) for c in [52, 56, 75])
VOACMC = "".join(chr(c) for c in [67, 70, 71, 51, 49])
VUBYGD = "".join(chr(c) for c in [82, 101, 115, 116, 114, 105, 99, 116, 101, 100])
VUNXNK = 327
VWVUBY = "".join(chr(c) for c in [80, 97, 99, 107, 76, 111, 103, 84, 114, 105, 103])
VXOIHB = 473
VYFCRT = "".join(chr(c) for c in [73, 78, 86, 65, 76, 73, 68, 95, 84, 89, 80, 69])
WAONPY = "".join(
    chr(c)
    for c in [
        82,
        101,
        109,
        111,
        116,
        101,
        70,
        105,
        108,
        116,
        68,
        117,
        114,
        80,
        101,
        114,
        68,
        97,
        121,
    ]
)
WBSIRY = "".join(chr(c) for c in [82, 104, 82, 101, 103, 83, 108, 111, 112, 101])
WDAFIK = "".join(chr(c) for c in [67, 70, 71, 52])
WIVDNQ = "".join(chr(c) for c in [83, 79, 117, 116, 53])
WJYKLG = "".join(
    chr(c)
    for c in [84, 104, 101, 114, 109, 105, 115, 116, 97, 110, 99, 101, 69, 114, 114]
)
WMNZMJ = 277
WRKINE = "".join(chr(c) for c in [80, 97, 99, 107, 66, 111, 111, 116, 82, 101, 118])
WSKWIV = 322
WVUBYG = 316
XBQFYL = 311
XCHWDA = 450
XEKVKZ = 290
XFEFJT = 271
XIBHZV = 476
XLSXUJ = "".join(chr(c) for c in [82, 69, 77, 79, 84, 69])
XNKMLO = "".join(chr(c) for c in [83, 79, 117, 116, 51, 67, 117, 114])
XNQTMF = "".join(chr(c) for c in [67, 70, 71, 49, 51])
XOIHBX = "".join(chr(c) for c in [67, 70, 71, 50, 54])
XPICXQ = 4
XQGLRA = "".join(chr(c) for c in [85, 100, 66, 76])
XQIEFX = "".join(chr(c) for c in [85, 100, 80, 52])
XQVXOI = 472
XSJWMN = "".join(
    chr(c) for c in [82, 101, 97, 108, 83, 101, 116, 80, 111, 105, 110, 116, 71]
)
XTIACQ = 7
XUJUTY = 263
XWAJVD = "".join(chr(c) for c in [67, 69])
XYBQSN = "".join(chr(c) for c in [68, 74, 83, 52])
YBQSNQ = "".join(chr(c) for c in [105, 110, 67, 108, 101, 97, 114])
YEKCWA = "".join(chr(c) for c in [65, 67, 84, 73, 86, 69])
YGDSBD = "".join(chr(c) for c in [75, 101, 121, 112, 97, 100, 84, 121, 112, 101])
YIYWSK = "".join(chr(c) for c in [83, 79, 117, 116, 50])
YKLGQP = "".join(chr(c) for c in [75, 105, 110, 80, 117, 109, 112, 79, 102, 102])
YLIUXF = 268
YLJUIK = 315
YMOUNB = "".join(chr(c) for c in [69, 88, 84, 82, 69, 77, 69])
YNQJYM = "".join(chr(c) for c in [83, 119, 109, 82, 105, 115, 107])
YOUSPB = "".join(
    chr(c) for c in [80, 114, 111, 103, 69, 99, 111, 110, 65, 99, 116, 105, 118, 101]
)
YPIPIV = 257
YWSKWI = "".join(chr(c) for c in [83, 79, 117, 116, 51])
YXBQFY = "".join(chr(c) for c in [105, 110, 84, 67, 105, 112, 68, 101, 108, 97, 121])
YYLIUX = "".join(
    chr(c) for c in [82, 101, 109, 111, 116, 101, 69, 99, 111, 110, 68, 117, 114]
)
YYPIPI = "".join(chr(c) for c in [81, 117, 105, 101, 116, 83, 116, 97, 116, 101])
ZCQBMJ = "".join(chr(c) for c in [82, 104, 87, 97, 116, 101, 114, 84, 101, 109, 112])
ZDGKEA = "".join(chr(c) for c in [67, 70, 71, 49, 54])
ZMJIGY = "".join(
    chr(c) for c in [84, 101, 109, 112, 78, 111, 116, 86, 97, 108, 105, 100]
)
ZTATDZ = "".join(chr(c) for c in [67, 70, 71, 49, 48])
ZVOACM = 478
ZXNQTM = 460
ACMCVD = []
AIIDNI = [QLAIID, LAIIDN]
BXTIAC = [NIBXTI, IBXTIA]
BYGDSB = [VUBYGD, UBYGDS]
CVDSSR = [
    ASSAKQ,
    PICXQI,
    CXQIEF,
    XQIEFX,
    IEFXQG,
    XQGLRA,
    RAHEOC,
    HEOCTH,
    OCTHBS,
    THBSKS,
    BSKSOK,
    KSOKPH,
    OKPHUO,
]
EKCWAO = [UJUTYE, JUTYEK, UTYEKC, TYEKCW, YEKCWA]
FXQGLR = [IVLASS, AKQXPI]
GLRAHE = [IVLASS, QGLRAH]
JRJHIU = [IVLASS, UOJRJH, OJRJHI]
KQXPIC = [IVLASS, SAKQXP, AKQXPI]
LSXUJU = [EXLSXU, XLSXUJ]
MCVDSS = [
    PHUOJR,
    RJHIUS,
    JHIUSO,
    HIUSOO,
    IUSOOQ,
    OOQNRS,
    OQNRSJ,
    QNRSJM,
    RSJMCB,
    SJMCBF,
    MCBFEG,
    CBFEGZ,
    CMCVDS,
]
MHXEKV = [
    JNIBXY,
    NIBXYB,
    IBXYBQ,
    BXYBQS,
    XYBQSN,
    YBQSNQ,
    BQSNQL,
    QSNQLN,
    SNQLNM,
    NQLNMH,
    QLNMHX,
    LNMHXE,
    NMHXEK,
]
MOUNBL = [QJYMOU, SAKQXP, JYMOUN, AKQXPI, YMOUNB]
NZMJIG = [HFTHEC, MNZMJI, MNZMJI, MNZMJI]
QGVUNX = [
    TBJEUT,
    HFTHEC,
    HFTHEC,
    HFTHEC,
    HFTHEC,
    HFTHEC,
    HFTHEC,
    HFTHEC,
    HFTHEC,
    HFTHEC,
    HFTHEC,
    HFTHEC,
    HFTHEC,
    HFTHEC,
    NQGVUN,
]
RYXBQF = [HFTHEC, IRYXBQ, IRYXBQ, IRYXBQ]
SELHBQ = [
    TBJEUT,
    HFTHEC,
    HFTHEC,
    HFTHEC,
    HFTHEC,
    HFTHEC,
    HFTHEC,
    HFTHEC,
    HFTHEC,
    HFTHEC,
    HFTHEC,
    OQNRSJ,
]
SOOQNR = [IVLASS, UOJRJH]
TYIYWS = [
    TBJEUT,
    BJEUTO,
    JEUTOP,
    EUTOPH,
    UTOPHU,
    TOPHUG,
    OPHUGT,
    PHUGTY,
    HUGTYI,
    IUSOOQ,
    UGTYIY,
    OQNRSJ,
    QNRSJM,
    RSJMCB,
    HFTHEC,
    HFTHEC,
    HFTHEC,
    HFTHEC,
    HFTHEC,
    GTYIYW,
]
VDQLAI = [OOQNRS, JVDQLA]
VLASSA = [PIPIVL, IPIVLA, PIVLAS, IVLASS]
VYYPIP = [
    VHFTHE,
    HFTHEC,
    HFTHEC,
    HFTHEC,
    HFTHEC,
    HFTHEC,
    HFTHEC,
    HFTHEC,
    HFTHEC,
    HFTHEC,
    HFTHEC,
    HFTHEC,
    HFTHEC,
    HFTHEC,
    HFTHEC,
    HFTHEC,
    HFTHEC,
    HFTHEC,
    HFTHEC,
    HFTHEC,
    FTHECV,
    THECVY,
    HECVYY,
    ECVYYP,
    HFTHEC,
    CVYYPI,
]
WAJVDQ = [LXWAJV, XWAJVD]
YFCRTF = [
    DSBDJQ,
    SBDJQR,
    BDJQRJ,
    DJQRJJ,
    JQRJJJ,
    QRJJJV,
    RJJJVY,
    JJJVYF,
    LNMHXE,
    HFTHEC,
    HFTHEC,
    HFTHEC,
    JJVYFC,
    JVYFCR,
    VYFCRT,
]
ZILXWA = [EKVKZI, KVKZIL, VKZILX, KZILXW]
ZUQEXL = [FEGZUQ, EGZUQE, GZUQEX]


class GeckoLogStruct:
    def __init__(self, struct_):
        self.struct = struct_

    @property
    def version(self):
        return VDSSRU

    @property
    def begin(self):
        return DSSRUR

    @property
    def end(self):
        return SSRURA

    @property
    def all_device_keys(self):
        return MCVDSS

    @property
    def user_demand_keys(self):
        return CVDSSR

    @property
    def accessors(self):
        return {
            ZCQBMJ: GeckoTempStructAccessor(self.struct, ZCQBMJ, CQBMJV, None),
            QBMJVH: GeckoByteStructAccessor(self.struct, QBMJVH, BMJVHF, None),
            MJVHFT: GeckoEnumStructAccessor(
                self.struct, MJVHFT, JVHFTH, None, VYYPIP, None, None, None
            ),
            YYPIPI: GeckoEnumStructAccessor(
                self.struct, YYPIPI, YPIPIV, None, VLASSA, None, None, LASSAK
            ),
            ASSAKQ: GeckoEnumStructAccessor(
                self.struct, ASSAKQ, SSAKQX, QXPICX, KQXPIC, None, XPICXQ, LASSAK
            ),
            PICXQI: GeckoEnumStructAccessor(
                self.struct, PICXQI, SSAKQX, ICXQIE, KQXPIC, None, XPICXQ, LASSAK
            ),
            CXQIEF: GeckoEnumStructAccessor(
                self.struct, CXQIEF, SSAKQX, XPICXQ, KQXPIC, None, XPICXQ, LASSAK
            ),
            XQIEFX: GeckoEnumStructAccessor(
                self.struct, XQIEFX, SSAKQX, QIEFXQ, KQXPIC, None, XPICXQ, LASSAK
            ),
            IEFXQG: GeckoEnumStructAccessor(
                self.struct, IEFXQG, EFXQGL, QXPICX, FXQGLR, None, ICXQIE, LASSAK
            ),
            XQGLRA: GeckoEnumStructAccessor(
                self.struct, XQGLRA, EFXQGL, LRAHEO, GLRAHE, None, ICXQIE, LASSAK
            ),
            RAHEOC: GeckoEnumStructAccessor(
                self.struct, RAHEOC, AHEOCT, None, GLRAHE, None, None, LASSAK
            ),
            HEOCTH: GeckoEnumStructAccessor(
                self.struct, HEOCTH, EOCTHB, None, FXQGLR, None, None, LASSAK
            ),
            OCTHBS: GeckoByteStructAccessor(self.struct, OCTHBS, CTHBSK, LASSAK),
            THBSKS: GeckoByteStructAccessor(self.struct, THBSKS, HBSKSO, LASSAK),
            BSKSOK: GeckoByteStructAccessor(self.struct, BSKSOK, SKSOKP, LASSAK),
            KSOKPH: GeckoByteStructAccessor(self.struct, KSOKPH, SOKPHU, LASSAK),
            OKPHUO: GeckoByteStructAccessor(self.struct, OKPHUO, KPHUOJ, LASSAK),
            PHUOJR: GeckoEnumStructAccessor(
                self.struct, PHUOJR, HUOJRJ, QXPICX, JRJHIU, None, XPICXQ, None
            ),
            RJHIUS: GeckoEnumStructAccessor(
                self.struct, RJHIUS, HUOJRJ, ICXQIE, JRJHIU, None, XPICXQ, None
            ),
            JHIUSO: GeckoEnumStructAccessor(
                self.struct, JHIUSO, HUOJRJ, XPICXQ, JRJHIU, None, XPICXQ, None
            ),
            HIUSOO: GeckoEnumStructAccessor(
                self.struct, HIUSOO, HUOJRJ, QIEFXQ, JRJHIU, None, XPICXQ, None
            ),
            IUSOOQ: GeckoEnumStructAccessor(
                self.struct, IUSOOQ, USOOQN, QXPICX, SOOQNR, None, ICXQIE, None
            ),
            OOQNRS: GeckoEnumStructAccessor(
                self.struct, OOQNRS, USOOQN, LRAHEO, GLRAHE, None, ICXQIE, None
            ),
            OQNRSJ: GeckoEnumStructAccessor(
                self.struct, OQNRSJ, USOOQN, ICXQIE, GLRAHE, None, ICXQIE, None
            ),
            QNRSJM: GeckoEnumStructAccessor(
                self.struct, QNRSJM, USOOQN, NRSJMC, GLRAHE, None, ICXQIE, None
            ),
            RSJMCB: GeckoEnumStructAccessor(
                self.struct, RSJMCB, USOOQN, XPICXQ, GLRAHE, None, ICXQIE, None
            ),
            SJMCBF: GeckoEnumStructAccessor(
                self.struct, SJMCBF, USOOQN, JMCBFE, GLRAHE, None, ICXQIE, None
            ),
            MCBFEG: GeckoEnumStructAccessor(
                self.struct, MCBFEG, USOOQN, QIEFXQ, GLRAHE, None, ICXQIE, None
            ),
            CBFEGZ: GeckoEnumStructAccessor(
                self.struct, CBFEGZ, BFEGZU, None, ZUQEXL, None, None, LASSAK
            ),
            UQEXLS: GeckoEnumStructAccessor(
                self.struct, UQEXLS, QEXLSX, QXPICX, LSXUJU, None, ICXQIE, LASSAK
            ),
            SXUJUT: GeckoEnumStructAccessor(
                self.struct, SXUJUT, XUJUTY, None, EKCWAO, None, None, LASSAK
            ),
            KCWAON: GeckoTimeStructAccessor(self.struct, KCWAON, CWAONP, LASSAK),
            WAONPY: GeckoByteStructAccessor(self.struct, WAONPY, AONPYY, LASSAK),
            ONPYYL: GeckoEnumStructAccessor(
                self.struct, ONPYYL, QEXLSX, ICXQIE, LSXUJU, None, ICXQIE, LASSAK
            ),
            NPYYLI: GeckoEnumStructAccessor(
                self.struct, NPYYLI, PYYLIU, None, EKCWAO, None, None, LASSAK
            ),
            YYLIUX: GeckoTimeStructAccessor(self.struct, YYLIUX, YLIUXF, LASSAK),
            LIUXFE: GeckoByteStructAccessor(self.struct, LIUXFE, IUXFEF, LASSAK),
            UXFEFJ: GeckoByteStructAccessor(self.struct, UXFEFJ, XFEFJT, LASSAK),
            FEFJTA: GeckoByteStructAccessor(self.struct, FEFJTA, EFJTAC, LASSAK),
            FJTACC: GeckoBoolStructAccessor(self.struct, FJTACC, JTACCP, QXPICX, None),
            TACCPQ: GeckoBoolStructAccessor(self.struct, TACCPQ, JTACCP, ICXQIE, None),
            ACCPQI: GeckoBoolStructAccessor(self.struct, ACCPQI, JTACCP, NRSJMC, None),
            CCPQIP: GeckoBoolStructAccessor(self.struct, CCPQIP, JTACCP, XPICXQ, None),
            CPQIPO: GeckoBoolStructAccessor(self.struct, CPQIPO, JTACCP, JMCBFE, None),
            PQIPOU: GeckoBoolStructAccessor(self.struct, PQIPOU, QIPOUY, ICXQIE, None),
            IPOUYN: GeckoBoolStructAccessor(self.struct, IPOUYN, POUYNQ, NRSJMC, None),
            OUYNQJ: GeckoBoolStructAccessor(self.struct, OUYNQJ, POUYNQ, JMCBFE, None),
            UYNQJY: GeckoBoolStructAccessor(self.struct, UYNQJY, POUYNQ, QIEFXQ, None),
            YNQJYM: GeckoEnumStructAccessor(
                self.struct, YNQJYM, NQJYMO, None, MOUNBL, None, None, None
            ),
            OUNBLK: GeckoBoolStructAccessor(self.struct, OUNBLK, UNBLKX, JMCBFE, None),
            NBLKXS: GeckoBoolStructAccessor(self.struct, NBLKXS, UNBLKX, QIEFXQ, None),
            BLKXSJ: GeckoWordStructAccessor(self.struct, BLKXSJ, LKXSJW, None),
            KXSJWM: GeckoBoolStructAccessor(self.struct, KXSJWM, QIPOUY, LRAHEO, None),
            XSJWMN: GeckoTempStructAccessor(self.struct, XSJWMN, SJWMNZ, None),
            JWMNZM: GeckoTempStructAccessor(self.struct, JWMNZM, WMNZMJ, None),
            MNZMJI: GeckoEnumStructAccessor(
                self.struct, MNZMJI, USOOQN, JMCBFE, NZMJIG, None, XPICXQ, None
            ),
            ZMJIGY: GeckoBoolStructAccessor(self.struct, ZMJIGY, MJIGYO, ICXQIE, None),
            JIGYOU: GeckoBoolStructAccessor(self.struct, JIGYOU, MJIGYO, QIEFXQ, None),
            IGYOUS: GeckoBoolStructAccessor(self.struct, IGYOUS, GYOUSP, ICXQIE, None),
            YOUSPB: GeckoBoolStructAccessor(self.struct, YOUSPB, OUSPBW, LRAHEO, None),
            USPBWJ: GeckoBoolStructAccessor(
                self.struct, USPBWJ, OUSPBW, ICXQIE, LASSAK
            ),
            SPBWJY: GeckoBoolStructAccessor(self.struct, SPBWJY, PBWJYK, LRAHEO, None),
            BWJYKL: GeckoBoolStructAccessor(self.struct, BWJYKL, QIPOUY, NRSJMC, None),
            WJYKLG: GeckoBoolStructAccessor(self.struct, WJYKLG, POUYNQ, QXPICX, None),
            JYKLGQ: GeckoBoolStructAccessor(self.struct, JYKLGQ, POUYNQ, LRAHEO, None),
            YKLGQP: GeckoBoolStructAccessor(self.struct, YKLGQP, KLGQPL, ICXQIE, None),
            LGQPLS: GeckoBoolStructAccessor(self.struct, LGQPLS, KLGQPL, NRSJMC, None),
            GQPLSP: GeckoBoolStructAccessor(self.struct, GQPLSP, QPLSPF, NRSJMC, None),
            PLSPFT: GeckoBoolStructAccessor(self.struct, PLSPFT, QPLSPF, XPICXQ, None),
            LSPFTS: GeckoBoolStructAccessor(self.struct, LSPFTS, QPLSPF, JMCBFE, None),
            SPFTSI: GeckoBoolStructAccessor(self.struct, SPFTSI, QPLSPF, QIEFXQ, None),
            PFTSIF: GeckoBoolStructAccessor(self.struct, PFTSIF, FTSIFJ, NRSJMC, None),
            TSIFJB: GeckoBoolStructAccessor(self.struct, TSIFJB, FTSIFJ, XPICXQ, None),
            SIFJBI: GeckoBoolStructAccessor(self.struct, SIFJBI, FTSIFJ, JMCBFE, None),
            IFJBIA: GeckoBoolStructAccessor(self.struct, IFJBIA, FTSIFJ, QIEFXQ, None),
            FJBIAM: GeckoBoolStructAccessor(self.struct, FJBIAM, JBIAMJ, ICXQIE, None),
            BIAMJM: GeckoBoolStructAccessor(self.struct, BIAMJM, JBIAMJ, NRSJMC, None),
            IAMJMA: GeckoBoolStructAccessor(self.struct, IAMJMA, PBWJYK, NRSJMC, None),
            AMJMAO: GeckoBoolStructAccessor(self.struct, AMJMAO, UNBLKX, QXPICX, None),
            MJMAOA: GeckoBoolStructAccessor(self.struct, MJMAOA, UNBLKX, LRAHEO, None),
            JMAOAW: GeckoBoolStructAccessor(self.struct, JMAOAW, MAOAWB, QXPICX, None),
            AOAWBS: GeckoBoolStructAccessor(self.struct, AOAWBS, GYOUSP, QXPICX, None),
            OAWBSI: GeckoBoolStructAccessor(self.struct, OAWBSI, KLGQPL, QXPICX, None),
            AWBSIR: GeckoBoolStructAccessor(self.struct, AWBSIR, KLGQPL, LRAHEO, None),
            WBSIRY: GeckoBoolStructAccessor(self.struct, WBSIRY, KLGQPL, XPICXQ, None),
            BSIRYX: GeckoBoolStructAccessor(self.struct, BSIRYX, SIRYXB, QXPICX, None),
            IRYXBQ: GeckoEnumStructAccessor(
                self.struct, IRYXBQ, SIRYXB, LRAHEO, RYXBQF, None, XPICXQ, None
            ),
            YXBQFY: GeckoWordStructAccessor(self.struct, YXBQFY, XBQFYL, None),
            BQFYLJ: GeckoBoolStructAccessor(self.struct, BQFYLJ, QFYLJU, QXPICX, None),
            FYLJUI: GeckoBoolStructAccessor(self.struct, FYLJUI, YLJUIK, QXPICX, None),
            LJUIKF: GeckoBoolStructAccessor(self.struct, LJUIKF, YLJUIK, LRAHEO, None),
            JUIKFW: GeckoBoolStructAccessor(self.struct, JUIKFW, JBIAMJ, QXPICX, None),
            UIKFWR: GeckoBoolStructAccessor(self.struct, UIKFWR, JBIAMJ, LRAHEO, None),
            IKFWRK: GeckoBoolStructAccessor(self.struct, IKFWRK, JBIAMJ, XPICXQ, None),
            KFWRKI: GeckoWordStructAccessor(self.struct, KFWRKI, FWRKIN, None),
            WRKINE: GeckoByteStructAccessor(self.struct, WRKINE, RKINEJ, None),
            KINEJN: GeckoByteStructAccessor(self.struct, KINEJN, INEJNI, None),
            NEJNIB: GeckoEnumStructAccessor(
                self.struct, NEJNIB, EJNIBX, None, MHXEKV, None, None, None
            ),
            HXEKVK: GeckoEnumStructAccessor(
                self.struct, HXEKVK, XEKVKZ, QXPICX, ZILXWA, None, XPICXQ, None
            ),
            ILXWAJ: GeckoEnumStructAccessor(
                self.struct, ILXWAJ, XEKVKZ, ICXQIE, WAJVDQ, None, ICXQIE, None
            ),
            AJVDQL: GeckoEnumStructAccessor(
                self.struct, AJVDQL, XEKVKZ, NRSJMC, VDQLAI, None, ICXQIE, None
            ),
            DQLAII: GeckoEnumStructAccessor(
                self.struct, DQLAII, XEKVKZ, XPICXQ, AIIDNI, None, ICXQIE, None
            ),
            IIDNIB: GeckoBoolStructAccessor(self.struct, IIDNIB, XEKVKZ, JMCBFE, None),
            IDNIBX: GeckoBoolStructAccessor(self.struct, IDNIBX, XEKVKZ, QIEFXQ, None),
            DNIBXT: GeckoEnumStructAccessor(
                self.struct, DNIBXT, XEKVKZ, XTIACQ, BXTIAC, None, ICXQIE, None
            ),
            TIACQF: GeckoWordStructAccessor(self.struct, TIACQF, IACQFF, None),
            ACQFFT: GeckoByteStructAccessor(self.struct, ACQFFT, CQFFTT, None),
            QFFTTI: GeckoByteStructAccessor(self.struct, QFFTTI, FFTTID, None),
            FTTIDU: GeckoByteStructAccessor(self.struct, FTTIDU, TTIDUB, None),
            TIDUBS: GeckoByteStructAccessor(self.struct, TIDUBS, IDUBSS, None),
            DUBSSU: GeckoWordStructAccessor(self.struct, DUBSSU, UBSSUH, None),
            BSSUHB: GeckoByteStructAccessor(self.struct, BSSUHB, SSUHBV, None),
            SUHBVW: GeckoByteStructAccessor(self.struct, SUHBVW, UHBVWV, None),
            HBVWVU: GeckoWordStructAccessor(self.struct, HBVWVU, BVWVUB, None),
            VWVUBY: GeckoEnumStructAccessor(
                self.struct, VWVUBY, WVUBYG, None, BYGDSB, None, ICXQIE, LASSAK
            ),
            YGDSBD: GeckoEnumStructAccessor(
                self.struct, YGDSBD, GDSBDJ, None, YFCRTF, None, None, None
            ),
            FCRTFM: GeckoWordStructAccessor(self.struct, FCRTFM, CRTFMN, None),
            RTFMNH: GeckoByteStructAccessor(self.struct, RTFMNH, TFMNHT, None),
            FMNHTB: GeckoByteStructAccessor(self.struct, FMNHTB, MNHTBJ, None),
            NHTBJE: GeckoEnumStructAccessor(
                self.struct, NHTBJE, HTBJEU, None, TYIYWS, None, None, LASSAK
            ),
            YIYWSK: GeckoEnumStructAccessor(
                self.struct, YIYWSK, IYWSKW, None, TYIYWS, None, None, LASSAK
            ),
            YWSKWI: GeckoEnumStructAccessor(
                self.struct, YWSKWI, WSKWIV, None, TYIYWS, None, None, LASSAK
            ),
            SKWIVD: GeckoEnumStructAccessor(
                self.struct, SKWIVD, KWIVDN, None, TYIYWS, None, None, LASSAK
            ),
            WIVDNQ: GeckoEnumStructAccessor(
                self.struct, WIVDNQ, IVDNQG, None, TYIYWS, None, None, LASSAK
            ),
            VDNQGV: GeckoEnumStructAccessor(
                self.struct, VDNQGV, DNQGVU, None, QGVUNX, None, None, LASSAK
            ),
            GVUNXN: GeckoByteStructAccessor(self.struct, GVUNXN, VUNXNK, LASSAK),
            UNXNKM: GeckoByteStructAccessor(self.struct, UNXNKM, NXNKML, LASSAK),
            XNKMLO: GeckoByteStructAccessor(self.struct, XNKMLO, NKMLOI, LASSAK),
            KMLOIJ: GeckoByteStructAccessor(self.struct, KMLOIJ, MLOIJU, LASSAK),
            LOIJUG: GeckoByteStructAccessor(self.struct, LOIJUG, OIJUGS, LASSAK),
            IJUGSE: GeckoByteStructAccessor(self.struct, IJUGSE, JUGSEL, LASSAK),
            UGSELH: GeckoEnumStructAccessor(
                self.struct, UGSELH, GSELHB, None, SELHBQ, None, None, LASSAK
            ),
            ELHBQN: GeckoByteStructAccessor(self.struct, ELHBQN, LHBQNR, LASSAK),
        }



#!/usr/bin/python3
"""
    GeckoConfigStruct - A class to manage the ConfigStruct for 'InYJ v54'
"""

from . import (
    GeckoByteStructAccessor,
    GeckoWordStructAccessor,
    GeckoTimeStructAccessor,
    GeckoBoolStructAccessor,
    GeckoEnumStructAccessor,
    GeckoTempStructAccessor,
)

# Constants for this class
ACCPQI = "".join(
    chr(c) for c in [79, 51, 83, 117, 115, 112, 101, 110, 100, 84, 105, 109, 101]
)
ACQFFT = "".join(chr(c) for c in [70, 114, 101, 101, 80, 117, 109, 112, 75, 101, 121])
AHEOCT = 39
AJVDQL = "".join(chr(c) for c in [83, 108, 97, 118, 101, 67, 111, 110, 102, 105, 103])
AKQXPI = "".join(chr(c) for c in [79, 117, 116, 51])
AMJMAO = "".join(chr(c) for c in [79, 117, 116, 50, 70, 117, 115, 101])
AOAWBS = "".join(chr(c) for c in [68, 105, 114, 101, 99, 116, 49, 70, 117, 115, 101])
AONPYY = "".join(chr(c) for c in [80, 49])
AWBSIR = "".join(chr(c) for c in [79, 117, 116, 72, 116, 114, 70, 117, 115, 101])
BFEGZU = 57
BIAMJM = "".join(chr(c) for c in [76, 105, 110, 101, 50])
BLKXSJ = "".join(chr(c) for c in [73, 110, 116, 111, 80, 105, 112, 105, 110, 103])
BMJVHF = "".join(chr(c) for c in [79, 117, 116, 49])
BQFYLJ = "".join(chr(c) for c in [70, 49, 76, 105, 110, 101])
BSIRYX = "".join(chr(c) for c in [70, 49, 67, 117, 114, 114, 101, 110, 116])
BSKSOK = "".join(chr(c) for c in [80, 117, 109, 112, 84, 105, 109, 101, 79, 117, 116])
BSSUHB = "".join(
    chr(c) for c in [75, 101, 121, 112, 97, 100, 79, 112, 116, 105, 111, 110, 115, 50]
)
BVWVUB = 46
BWJYKL = 51
BXYBQS = "".join(
    chr(c)
    for c in [
        69,
        99,
        111,
        110,
        80,
        114,
        111,
        103,
        65,
        118,
        97,
        105,
        108,
        97,
        98,
        108,
        101,
    ]
)
CBFEGZ = "".join(chr(c) for c in [79, 116, 79, 112, 116, 105, 111, 110])
CCPQIP = 63
CPQIPO = "".join(chr(c) for c in [83, 101, 116, 112, 111, 105, 110, 116, 71])
CQBMJV = 0
CQFFTT = "".join(chr(c) for c in [76, 97, 115, 116, 80, 117, 109, 112, 75, 101, 121])
CVYYPI = "".join(chr(c) for c in [80, 52, 72])
CWAONP = "".join(chr(c) for c in [68, 114, 97, 105, 110, 77, 111, 100, 101])
CXQIEF = 36
DNIBXT = "".join(
    chr(c)
    for c in [80, 117, 109, 112, 49, 85, 115, 101, 114, 65, 99, 99, 101, 115, 115]
)
DQLAII = 34
DUBSSU = "".join(
    chr(c) for c in [75, 101, 121, 112, 97, 100, 79, 112, 116, 105, 111, 110, 115, 49]
)
ECVYYP = "".join(chr(c) for c in [80, 51, 76])
EFJTAC = 30
EFXQGL = 38
EGZUQE = "".join(
    chr(c) for c in [65, 108, 119, 97, 121, 115, 69, 110, 97, 98, 108, 101, 100]
)
EJNIBX = "".join(chr(c) for c in [69, 99, 111, 110, 83, 116, 97, 114, 116])
EKCWAO = "".join(
    chr(c)
    for c in [70, 105, 108, 116, 83, 117, 115, 112, 101, 110, 100, 84, 105, 109, 101]
)
EKVKZI = 76
EOCTHB = 79
EXLSXU = "".join(chr(c) for c in [72, 105])
FEFJTA = "".join(chr(c) for c in [79, 51, 84, 121, 112, 101])
FEGZUQ = "".join(chr(c) for c in [68, 105, 115, 97, 98, 108, 101, 100])
FFTTID = 5
FJBIAM = "".join(chr(c) for c in [70, 51])
FJTACC = "".join(chr(c) for c in [83, 116, 97, 110, 100, 97, 114, 100])
FTHECV = "".join(chr(c) for c in [80, 50, 72])
FTSIFJ = "".join(chr(c) for c in [79, 117, 116, 49, 70, 117, 115, 101])
FTTIDU = "".join(
    chr(c)
    for c in [72, 101, 97, 116, 101, 114, 83, 111, 102, 116, 83, 116, 97, 114, 116]
)
FWRKIN = "".join(chr(c) for c in [70, 105, 108, 116, 83, 116, 97, 114, 116])
FXQGLR = "".join(chr(c) for c in [79, 117, 116, 72, 116, 82, 67, 117, 114])
GLRAHE = 15
GQPLSP = "".join(
    chr(c) for c in [73, 110, 112, 117, 116, 67, 117, 114, 114, 101, 110, 116]
)
GZUQEX = "".join(
    chr(c) for c in [87, 105, 116, 104, 83, 80, 79, 118, 101, 114, 57, 53, 70]
)
HBSKSO = 80
HBVWVU = "".join(
    chr(c) for c in [75, 101, 121, 112, 97, 100, 79, 112, 116, 105, 111, 110, 115, 52]
)
HECVYY = "".join(chr(c) for c in [80, 51, 72])
HEOCTH = "".join(chr(c) for c in [79, 117, 116, 76, 105])
HFTHEC = "".join(chr(c) for c in [80, 49, 76])
HIUSOO = "".join(
    chr(c) for c in [70, 105, 108, 116, 73, 110, 116, 101, 114, 102, 97, 99, 101]
)
HUOJRJ = 81
HXEKVK = "".join(
    chr(c)
    for c in [
        67,
        108,
        101,
        97,
        110,
        117,
        112,
        79,
        110,
        67,
        117,
        115,
        116,
        111,
        109,
        75,
        101,
        121,
    ]
)
IACQFF = "".join(
    chr(c)
    for c in [66, 108, 111, 119, 101, 114, 75, 101, 121, 79, 112, 116, 105, 111, 110]
)
IBXTIA = "".join(
    chr(c) for c in [72, 105, 103, 104, 83, 112, 101, 101, 100, 79, 110, 108, 121]
)
IBXYBQ = 10
ICXQIE = "".join(chr(c) for c in [79, 117, 116, 49, 67, 117, 114])
IDNIBX = 64
IDUBSS = 7
IEFXQG = "".join(chr(c) for c in [79, 117, 116, 51, 67, 117, 114])
IFJBIA = "".join(chr(c) for c in [70, 50])
IGYOUS = "".join(chr(c) for c in [78, 105, 103, 104, 116])
IIDNIB = "".join(
    chr(c)
    for c in [65, 109, 98, 105, 97, 110, 116, 79, 72, 84, 114, 105, 103, 65, 68, 67]
)
IKFWRK = "".join(chr(c) for c in [70, 105, 108, 116, 70, 114, 101, 113])
ILXWAJ = 73
INEJNI = "".join(chr(c) for c in [70, 105, 108, 116, 68, 117, 114, 50])
IPIVLA = "".join(chr(c) for c in [79, 51])
IPOUYN = 33
IRYXBQ = "".join(chr(c) for c in [70, 50, 67, 117, 114, 114, 101, 110, 116])
IUSOOQ = 32
IUXFEF = "".join(chr(c) for c in [79, 51, 80, 117, 109, 112])
IVLASS = "".join(chr(c) for c in [72, 84, 82])
JBIAMJ = "".join(chr(c) for c in [76, 105, 110, 101, 49])
JHIUSO = 2
JIGYOU = 70
JMAOAW = "".join(chr(c) for c in [79, 117, 116, 51, 70, 117, 115, 101])
JMCBFE = "".join(chr(c) for c in [65, 76, 87, 65, 89, 83, 95, 79, 78])
JNIBXY = 8
JTACCP = "".join(chr(c) for c in [84, 111, 103, 103, 108, 101])
JUIKFW = "".join(chr(c) for c in [70, 51, 76, 105, 110, 101])
JUTYEK = "".join(
    chr(c)
    for c in [
        67,
        112,
        79,
        102,
        102,
        84,
        105,
        109,
        101,
        68,
        117,
        114,
        105,
        110,
        103,
        79,
        84,
    ]
)
JVDQLA = 75
JVHFTH = "".join(chr(c) for c in [78, 65])
JWMNZM = 35
JYKLGQ = "".join(chr(c) for c in [67, 69])
JYMOUN = 25
KCWAON = 62
KFWRKI = 3
KINEJN = 6
KLGQPL = "".join(chr(c) for c in [78, 98, 80, 104, 97, 115, 101, 115])
KPHUOJ = 56
KQXPIC = 14
KSOKPH = "".join(
    chr(c) for c in [76, 105, 103, 104, 116, 84, 105, 109, 101, 79, 117, 116]
)
KVKZIL = "".join(
    chr(c) for c in [78, 111, 66, 108, 111, 119, 101, 114, 79, 110, 73, 50, 67]
)
LAIIDN = "".join(chr(c) for c in [50, 52, 104])
LASSAK = "".join(chr(c) for c in [70, 117, 108, 108, 79, 110])
LGQPLS = 52
LJUIKF = 105
LKXSJW = "".join(chr(c) for c in [73, 110, 116, 111, 84, 117, 98])
LNMHXE = "".join(
    chr(c)
    for c in [83, 111, 97, 107, 79, 110, 67, 117, 115, 116, 111, 109, 75, 101, 121]
)
LSPFTS = 74
LSXUJU = "".join(chr(c) for c in [79, 84, 84, 114, 105, 103, 103, 101, 114, 71])
LXWAJV = "".join(chr(c) for c in [77, 97, 115, 116, 101, 114])
MAOAWB = 85
MHXEKV = 1
MJIGYO = "".join(chr(c) for c in [69, 99, 111, 110, 84, 121, 112, 101])
MJMAOA = 84
MJVHFT = 12
MNZMJI = 66
MOUNBL = "".join(
    chr(c) for c in [78, 111, 116, 73, 110, 115, 116, 97, 108, 108, 101, 100]
)
NBLKXS = "".join(
    chr(c) for c in [80, 114, 111, 98, 101, 76, 111, 99, 97, 116, 105, 111, 110]
)
NEJNIB = 23
NIBXTI = "".join(chr(c) for c in [66, 111, 116, 104, 83, 112, 101, 101, 100, 115])
NIBXYB = "".join(chr(c) for c in [69, 99, 111, 110, 68, 117, 114])
NMHXEK = "".join(
    chr(c) for c in [79, 102, 102, 79, 110, 67, 117, 115, 116, 111, 109, 75, 101, 121]
)
NPYYLI = "".join(chr(c) for c in [79, 51, 85, 115, 97, 103, 101])
NQJYMO = 31
NQLNMH = "".join(
    chr(c)
    for c in [
        69,
        99,
        111,
        110,
        67,
        111,
        110,
        116,
        114,
        111,
        108,
        97,
        98,
        108,
        101,
        77,
        97,
        110,
        117,
        97,
        108,
        108,
        121,
    ]
)
NRSJMC = "".join(chr(c) for c in [67, 112, 85, 115, 97, 103, 101])
NZMJIG = "".join(
    chr(c) for c in [77, 97, 120, 83, 101, 116, 112, 111, 105, 110, 116, 71]
)
OAWBSI = 86
OCTHBS = "".join(chr(c) for c in [76, 73])
OJRJHI = "".join(chr(c) for c in [79, 119, 110])
OKPHUO = "".join(chr(c) for c in [76, 49, 50, 48, 84, 105, 109, 101, 79, 117, 116])
OOQNRS = "".join(chr(c) for c in [70, 105, 108, 116, 80, 49])
OQNRSJ = "".join(
    chr(c) for c in [70, 105, 108, 116, 80, 49, 68, 117, 114, 79, 110, 108, 121]
)
OUNBLK = "".join(
    chr(c) for c in [80, 114, 101, 115, 115, 117, 114, 101, 83, 119, 105, 116, 99, 104]
)
OUSPBW = 77
OUYNQJ = "".join(chr(c) for c in [67])
PBWJYK = "".join(chr(c) for c in [85, 76, 95, 67, 69])
PHUOJR = "".join(chr(c) for c in [76, 49, 50, 48, 84, 105, 109, 101, 114])
PIPIVL = "".join(chr(c) for c in [67, 80])
PIVLAS = "".join(chr(c) for c in [76, 49, 50, 48])
PLSPFT = "".join(chr(c) for c in [73, 110, 112, 117, 116, 77, 101, 110, 117])
POUYNQ = "".join(chr(c) for c in [70])
PQIPOU = 1
PYYLIU = 28
QBMJVH = "".join(chr(c) for c in [65, 76, 76])
QEXLSX = "".join(chr(c) for c in [76, 111])
QFYLJU = 104
QGLRAH = "".join(chr(c) for c in [68, 105, 114, 101, 99, 116])
QIEFXQ = 37
QIPOUY = "".join(chr(c) for c in [84, 101, 109, 112, 85, 110, 105, 116, 115])
QJYMOU = "".join(
    chr(c) for c in [70, 108, 111, 119, 68, 101, 116, 101, 99, 116, 111, 114]
)
QLAIID = "".join(chr(c) for c in [65, 109, 80, 109])
QLNMHX = 72
QPLSPF = 53
QSNQLN = "".join(chr(c) for c in [85, 68, 80, 114, 111, 103, 69, 99, 111, 110])
QXPICX = "".join(chr(c) for c in [79, 117, 116, 72, 116, 114])
RAHEOC = "".join(chr(c) for c in [68, 105, 114, 101, 99, 116, 67, 117, 114])
RJHIUS = 0
RKINEJ = "".join(chr(c) for c in [70, 105, 108, 116, 68, 117, 114])
RSJMCB = 27
RYXBQF = 99
SAKQXP = 13
SIFJBI = "".join(chr(c) for c in [70, 49])
SIRYXB = 98
SJMCBF = "".join(chr(c) for c in [83, 84, 65, 78, 68, 65, 82, 68])
SJWMNZ = "".join(
    chr(c) for c in [67, 111, 111, 108, 100, 111, 119, 110, 84, 105, 109, 101]
)
SKSOKP = 54
SNQLNM = 82
SOKPHU = 55
SOOQNR = "".join(chr(c) for c in [70, 105, 108, 116, 67, 80])
SPBWJY = 26
SPFTSI = "".join(chr(c) for c in [68, 117, 97, 108, 80, 97, 99, 107])
SSAKQX = "".join(chr(c) for c in [79, 117, 116, 50])
SSUHBV = 44
SUHBVW = "".join(
    chr(c) for c in [75, 101, 121, 112, 97, 100, 79, 112, 116, 105, 111, 110, 115, 51]
)
SXUJUT = 58
THBSKS = "".join(chr(c) for c in [76, 105, 103, 104, 116, 73, 110, 116, 115])
THECVY = "".join(chr(c) for c in [80, 50, 76])
TIACQF = 4
TIDUBS = "".join(
    chr(c) for c in [72, 101, 97, 116, 101, 114, 83, 111, 102, 116, 83, 116, 111, 112]
)
TSIFJB = 83
TTIDUB = 6
TYEKCW = "".join(
    chr(c)
    for c in [
        70,
        105,
        108,
        116,
        79,
        110,
        84,
        105,
        109,
        101,
        68,
        117,
        114,
        105,
        110,
        103,
        79,
        84,
    ]
)
UBSSUH = 43
UBYGDS = 54
UHBVWV = 45
UIKFWR = 106
UJUTYE = 59
UOJRJH = "".join(chr(c) for c in [83, 104, 97, 114, 101, 100])
UQEXLS = "".join(chr(c) for c in [80, 117, 114, 103, 101, 83, 112, 101, 101, 100])
USOOQN = "".join(chr(c) for c in [80, 117, 114, 103, 101, 79, 110, 108, 121])
USPBWJ = "".join(
    chr(c)
    for c in [
        77,
        97,
        120,
        78,
        117,
        109,
        98,
        101,
        114,
        79,
        102,
        80,
        104,
        97,
        115,
        101,
        115,
    ]
)
UTYEKC = 60
UXFEFJ = 29
VDQLAI = "".join(chr(c) for c in [84, 105, 109, 101, 70, 111, 114, 109, 97, 116])
VHFTHE = "".join(chr(c) for c in [80, 49, 72])
VKZILX = "".join(chr(c) for c in [66, 108, 111, 119, 101, 114, 79, 110, 73, 50, 67])
VLASSA = "".join(chr(c) for c in [])
VYYPIP = "".join(chr(c) for c in [80, 52, 76])
WAONPY = 78
WBSIRY = 87
WJYKLG = "".join(chr(c) for c in [85, 76])
WMNZMJ = "".join(
    chr(c) for c in [77, 105, 110, 83, 101, 116, 112, 111, 105, 110, 116, 71]
)
WRKINE = 4
XBQFYL = 100
XEKVKZ = "".join(
    chr(c) for c in [77, 117, 108, 116, 105, 75, 101, 121, 79, 112, 116, 105, 111, 110]
)
XPICXQ = 16
XQGLRA = 40
XQIEFX = "".join(chr(c) for c in [79, 117, 116, 50, 67, 117, 114])
XSJWMN = 3
XTIACQ = "".join(
    chr(c) for c in [83, 101, 108, 102, 67, 108, 101, 97, 110, 77, 115, 103]
)
XUJUTY = "".join(
    chr(c)
    for c in [67, 112, 79, 110, 84, 105, 109, 101, 68, 117, 114, 105, 110, 103, 79, 84]
)
XWAJVD = "".join(chr(c) for c in [83, 108, 97, 118, 101])
XYBQSN = 71
YBQSNQ = "".join(
    chr(c) for c in [79, 85, 84, 83, 73, 68, 69, 95, 70, 73, 76, 84, 69, 82]
)
YEKCWA = 61
YLIUXF = "".join(chr(c) for c in [65, 108, 119, 97, 121, 115])
YLJUIK = "".join(chr(c) for c in [70, 50, 76, 105, 110, 101])
YMOUNB = "".join(chr(c) for c in [105, 110, 70, 108, 111])
YNQJYM = "".join(chr(c) for c in [72, 101, 97, 116, 101, 114, 80, 117, 109, 112])
YOUSPB = "".join(
    chr(c) for c in [78, 111, 72, 101, 97, 116, 80, 101, 114, 105, 111, 100]
)
YPIPIV = "".join(chr(c) for c in [66, 76, 79])
YXBQFY = "".join(chr(c) for c in [70, 51, 67, 117, 114, 114, 101, 110, 116])
YYLIUX = "".join(chr(c) for c in [70, 105, 108, 116, 101, 114])
YYPIPI = "".join(chr(c) for c in [80, 53])
ZCQBMJ = "".join(
    chr(c) for c in [67, 111, 110, 102, 105, 103, 78, 117, 109, 98, 101, 114]
)
ZILXWA = "".join(chr(c) for c in [77, 97, 115, 116, 101, 114, 83, 108, 97, 118, 101])
ZMJIGY = 68
AIIDNI = [JVHFTH, QLAIID, LAIIDN]
ASSAKQ = [
    JVHFTH,
    VHFTHE,
    HFTHEC,
    FTHECV,
    THECVY,
    HECVYY,
    ECVYYP,
    CVYYPI,
    VYYPIP,
    YYPIPI,
    YPIPIV,
    PIPIVL,
    IPIVLA,
    PIVLAS,
    IVLASS,
    VLASSA,
    VLASSA,
    VLASSA,
    VLASSA,
    LASSAK,
]
BQSNQL = [JVHFTH, SJMCBF, YBQSNQ]
BXTIAC = [NIBXTI, IBXTIA]
CTHBSK = [
    VLASSA,
    VLASSA,
    VLASSA,
    VLASSA,
    VLASSA,
    VLASSA,
    VLASSA,
    VLASSA,
    VLASSA,
    VLASSA,
    VLASSA,
    VLASSA,
    VLASSA,
    VLASSA,
    VLASSA,
    OCTHBS,
]
FYLJUI = [VLASSA, VLASSA, VLASSA, VLASSA, VLASSA, VLASSA, JBIAMJ, BIAMJM]
GYOUSP = [FJTACC, IGYOUS]
IAMJMA = [SIFJBI, IFJBIA, FJBIAM, VLASSA, VLASSA, VLASSA, JBIAMJ, BIAMJM]
JRJHIU = [UOJRJH, OJRJHI]
KXSJWM = [BLKXSJ, LKXSJW]
KZILXW = [KVKZIL, VKZILX]
LIUXFE = [YYLIUX, YLIUXF]
LRAHEO = [
    JVHFTH,
    VLASSA,
    VLASSA,
    VLASSA,
    VLASSA,
    VLASSA,
    VLASSA,
    VLASSA,
    VLASSA,
    VLASSA,
    VLASSA,
    PIPIVL,
]
MCBFEG = [SJMCBF, JMCBFE]
ONPYYL = [JVHFTH, AONPYY, PIPIVL]
PFTSIF = [FJTACC, SPFTSI]
PICXQI = [
    JVHFTH,
    VHFTHE,
    VLASSA,
    VLASSA,
    VLASSA,
    VLASSA,
    VLASSA,
    VLASSA,
    VLASSA,
    VLASSA,
    VLASSA,
    VLASSA,
    VLASSA,
    VLASSA,
    IVLASS,
]
QFFTTI = [ACQFFT, CQFFTT]
QNRSJM = [USOOQN, SOOQNR, OOQNRS, OQNRSJ]
TACCPQ = [FJTACC, JTACCP]
UNBLKX = [YMOUNB, MOUNBL, OUNBLK]
UYNQJY = [POUYNQ, OUYNQJ]
VUBYGD = []
VWVUBY = [BMJVHF, SSAKQX, AKQXPI, QXPICX, QGLRAH, HEOCTH]
WAJVDQ = [VLASSA, LXWAJV, XWAJVD]
WVUBYG = [OCTHBS]
XFEFJT = [PIPIVL, AONPYY]
XLSXUJ = [QEXLSX, EXLSXU]
YKLGQP = [WJYKLG, JYKLGQ]
ZUQEXL = [FEGZUQ, EGZUQE, GZUQEX]


class GeckoConfigStruct:
    def __init__(self, struct_):
        self.struct = struct_

    @property
    def version(self):
        return UBYGDS

    @property
    def output_keys(self):
        return VWVUBY

    @property
    def accessors(self):
        return {
            ZCQBMJ: GeckoByteStructAccessor(self.struct, ZCQBMJ, CQBMJV, QBMJVH),
            BMJVHF: GeckoEnumStructAccessor(
                self.struct, BMJVHF, MJVHFT, None, ASSAKQ, None, None, QBMJVH
            ),
            SSAKQX: GeckoEnumStructAccessor(
                self.struct, SSAKQX, SAKQXP, None, ASSAKQ, None, None, QBMJVH
            ),
            AKQXPI: GeckoEnumStructAccessor(
                self.struct, AKQXPI, KQXPIC, None, ASSAKQ, None, None, QBMJVH
            ),
            QXPICX: GeckoEnumStructAccessor(
                self.struct, QXPICX, XPICXQ, None, PICXQI, None, None, QBMJVH
            ),
            ICXQIE: GeckoByteStructAccessor(self.struct, ICXQIE, CXQIEF, QBMJVH),
            XQIEFX: GeckoByteStructAccessor(self.struct, XQIEFX, QIEFXQ, QBMJVH),
            IEFXQG: GeckoByteStructAccessor(self.struct, IEFXQG, EFXQGL, QBMJVH),
            FXQGLR: GeckoByteStructAccessor(self.struct, FXQGLR, XQGLRA, QBMJVH),
            QGLRAH: GeckoEnumStructAccessor(
                self.struct, QGLRAH, GLRAHE, None, LRAHEO, None, None, QBMJVH
            ),
            RAHEOC: GeckoByteStructAccessor(self.struct, RAHEOC, AHEOCT, QBMJVH),
            HEOCTH: GeckoEnumStructAccessor(
                self.struct, HEOCTH, EOCTHB, None, CTHBSK, None, None, None
            ),
            THBSKS: GeckoByteStructAccessor(self.struct, THBSKS, HBSKSO, None),
            BSKSOK: GeckoByteStructAccessor(self.struct, BSKSOK, SKSOKP, QBMJVH),
            KSOKPH: GeckoByteStructAccessor(self.struct, KSOKPH, SOKPHU, QBMJVH),
            OKPHUO: GeckoByteStructAccessor(self.struct, OKPHUO, KPHUOJ, QBMJVH),
            PHUOJR: GeckoEnumStructAccessor(
                self.struct, PHUOJR, HUOJRJ, RJHIUS, JRJHIU, None, JHIUSO, QBMJVH
            ),
            HIUSOO: GeckoEnumStructAccessor(
                self.struct, HIUSOO, IUSOOQ, None, QNRSJM, None, None, QBMJVH
            ),
            NRSJMC: GeckoEnumStructAccessor(
                self.struct, NRSJMC, RSJMCB, None, MCBFEG, None, None, QBMJVH
            ),
            CBFEGZ: GeckoEnumStructAccessor(
                self.struct, CBFEGZ, BFEGZU, None, ZUQEXL, None, None, QBMJVH
            ),
            UQEXLS: GeckoEnumStructAccessor(
                self.struct, UQEXLS, HUOJRJ, JHIUSO, XLSXUJ, None, JHIUSO, QBMJVH
            ),
            LSXUJU: GeckoByteStructAccessor(self.struct, LSXUJU, SXUJUT, QBMJVH),
            XUJUTY: GeckoByteStructAccessor(self.struct, XUJUTY, UJUTYE, QBMJVH),
            JUTYEK: GeckoByteStructAccessor(self.struct, JUTYEK, UTYEKC, QBMJVH),
            TYEKCW: GeckoByteStructAccessor(self.struct, TYEKCW, YEKCWA, QBMJVH),
            EKCWAO: GeckoByteStructAccessor(self.struct, EKCWAO, KCWAON, QBMJVH),
            CWAONP: GeckoEnumStructAccessor(
                self.struct, CWAONP, WAONPY, None, ONPYYL, None, None, QBMJVH
            ),
            NPYYLI: GeckoEnumStructAccessor(
                self.struct, NPYYLI, PYYLIU, None, LIUXFE, None, None, QBMJVH
            ),
            IUXFEF: GeckoEnumStructAccessor(
                self.struct, IUXFEF, UXFEFJ, None, XFEFJT, None, None, QBMJVH
            ),
            FEFJTA: GeckoEnumStructAccessor(
                self.struct, FEFJTA, EFJTAC, None, TACCPQ, None, None, QBMJVH
            ),
            ACCPQI: GeckoByteStructAccessor(self.struct, ACCPQI, CCPQIP, QBMJVH),
            CPQIPO: GeckoTempStructAccessor(self.struct, CPQIPO, PQIPOU, QBMJVH),
            QIPOUY: GeckoEnumStructAccessor(
                self.struct, QIPOUY, IPOUYN, None, UYNQJY, None, None, QBMJVH
            ),
            YNQJYM: GeckoEnumStructAccessor(
                self.struct, YNQJYM, NQJYMO, None, XFEFJT, None, None, QBMJVH
            ),
            QJYMOU: GeckoEnumStructAccessor(
                self.struct, QJYMOU, JYMOUN, None, UNBLKX, None, None, QBMJVH
            ),
            NBLKXS: GeckoEnumStructAccessor(
                self.struct, NBLKXS, HUOJRJ, XSJWMN, KXSJWM, None, JHIUSO, QBMJVH
            ),
            SJWMNZ: GeckoByteStructAccessor(self.struct, SJWMNZ, JWMNZM, QBMJVH),
            WMNZMJ: GeckoTempStructAccessor(self.struct, WMNZMJ, MNZMJI, QBMJVH),
            NZMJIG: GeckoTempStructAccessor(self.struct, NZMJIG, ZMJIGY, QBMJVH),
            MJIGYO: GeckoEnumStructAccessor(
                self.struct, MJIGYO, JIGYOU, None, GYOUSP, None, None, QBMJVH
            ),
            YOUSPB: GeckoByteStructAccessor(self.struct, YOUSPB, OUSPBW, QBMJVH),
            USPBWJ: GeckoByteStructAccessor(self.struct, USPBWJ, SPBWJY, QBMJVH),
            PBWJYK: GeckoEnumStructAccessor(
                self.struct, PBWJYK, BWJYKL, None, YKLGQP, None, None, QBMJVH
            ),
            KLGQPL: GeckoByteStructAccessor(self.struct, KLGQPL, LGQPLS, QBMJVH),
            GQPLSP: GeckoByteStructAccessor(self.struct, GQPLSP, QPLSPF, QBMJVH),
            PLSPFT: GeckoEnumStructAccessor(
                self.struct, PLSPFT, LSPFTS, None, PFTSIF, None, None, QBMJVH
            ),
            FTSIFJ: GeckoEnumStructAccessor(
                self.struct, FTSIFJ, TSIFJB, None, IAMJMA, None, None, QBMJVH
            ),
            AMJMAO: GeckoEnumStructAccessor(
                self.struct, AMJMAO, MJMAOA, None, IAMJMA, None, None, QBMJVH
            ),
            JMAOAW: GeckoEnumStructAccessor(
                self.struct, JMAOAW, MAOAWB, None, IAMJMA, None, None, QBMJVH
            ),
            AOAWBS: GeckoEnumStructAccessor(
                self.struct, AOAWBS, OAWBSI, None, IAMJMA, None, None, QBMJVH
            ),
            AWBSIR: GeckoEnumStructAccessor(
                self.struct, AWBSIR, WBSIRY, None, IAMJMA, None, None, QBMJVH
            ),
            BSIRYX: GeckoByteStructAccessor(self.struct, BSIRYX, SIRYXB, QBMJVH),
            IRYXBQ: GeckoByteStructAccessor(self.struct, IRYXBQ, RYXBQF, QBMJVH),
            YXBQFY: GeckoByteStructAccessor(self.struct, YXBQFY, XBQFYL, QBMJVH),
            BQFYLJ: GeckoEnumStructAccessor(
                self.struct, BQFYLJ, QFYLJU, None, FYLJUI, None, None, QBMJVH
            ),
            YLJUIK: GeckoEnumStructAccessor(
                self.struct, YLJUIK, LJUIKF, None, FYLJUI, None, None, QBMJVH
            ),
            JUIKFW: GeckoEnumStructAccessor(
                self.struct, JUIKFW, UIKFWR, None, FYLJUI, None, None, QBMJVH
            ),
            IKFWRK: GeckoByteStructAccessor(self.struct, IKFWRK, KFWRKI, QBMJVH),
            FWRKIN: GeckoTimeStructAccessor(self.struct, FWRKIN, WRKINE, QBMJVH),
            RKINEJ: GeckoTimeStructAccessor(self.struct, RKINEJ, KINEJN, QBMJVH),
            INEJNI: GeckoTimeStructAccessor(self.struct, INEJNI, NEJNIB, QBMJVH),
            EJNIBX: GeckoTimeStructAccessor(self.struct, EJNIBX, JNIBXY, QBMJVH),
            NIBXYB: GeckoTimeStructAccessor(self.struct, NIBXYB, IBXYBQ, QBMJVH),
            BXYBQS: GeckoEnumStructAccessor(
                self.struct, BXYBQS, XYBQSN, None, BQSNQL, None, None, QBMJVH
            ),
            QSNQLN: GeckoBoolStructAccessor(
                self.struct, QSNQLN, SNQLNM, RJHIUS, QBMJVH
            ),
            NQLNMH: GeckoBoolStructAccessor(
                self.struct, NQLNMH, QLNMHX, JHIUSO, QBMJVH
            ),
            LNMHXE: GeckoBoolStructAccessor(
                self.struct, LNMHXE, QLNMHX, RJHIUS, QBMJVH
            ),
            NMHXEK: GeckoBoolStructAccessor(
                self.struct, NMHXEK, QLNMHX, MHXEKV, QBMJVH
            ),
            HXEKVK: GeckoBoolStructAccessor(
                self.struct, HXEKVK, QLNMHX, XSJWMN, QBMJVH
            ),
            XEKVKZ: GeckoEnumStructAccessor(
                self.struct, XEKVKZ, EKVKZI, None, KZILXW, None, None, QBMJVH
            ),
            ZILXWA: GeckoEnumStructAccessor(
                self.struct, ZILXWA, ILXWAJ, None, WAJVDQ, None, None, QBMJVH
            ),
            AJVDQL: GeckoByteStructAccessor(self.struct, AJVDQL, JVDQLA, QBMJVH),
            VDQLAI: GeckoEnumStructAccessor(
                self.struct, VDQLAI, DQLAII, None, AIIDNI, None, None, QBMJVH
            ),
            IIDNIB: GeckoWordStructAccessor(self.struct, IIDNIB, IDNIBX, QBMJVH),
            DNIBXT: GeckoEnumStructAccessor(
                self.struct, DNIBXT, HUOJRJ, MHXEKV, BXTIAC, None, JHIUSO, QBMJVH
            ),
            XTIACQ: GeckoBoolStructAccessor(
                self.struct, XTIACQ, HUOJRJ, TIACQF, QBMJVH
            ),
            IACQFF: GeckoEnumStructAccessor(
                self.struct, IACQFF, HUOJRJ, FFTTID, QFFTTI, None, JHIUSO, QBMJVH
            ),
            FTTIDU: GeckoBoolStructAccessor(
                self.struct, FTTIDU, HUOJRJ, TTIDUB, QBMJVH
            ),
            TIDUBS: GeckoBoolStructAccessor(
                self.struct, TIDUBS, HUOJRJ, IDUBSS, QBMJVH
            ),
            DUBSSU: GeckoByteStructAccessor(self.struct, DUBSSU, UBSSUH, QBMJVH),
            BSSUHB: GeckoByteStructAccessor(self.struct, BSSUHB, SSUHBV, QBMJVH),
            SUHBVW: GeckoByteStructAccessor(self.struct, SUHBVW, UHBVWV, QBMJVH),
            HBVWVU: GeckoByteStructAccessor(self.struct, HBVWVU, BVWVUB, QBMJVH),
        }



""" Gecko Pumps """

import logging

from .base import GeckoAutomationFacadeBase
from .sensors import GeckoSensor

logger = logging.getLogger(__name__)


class GeckoPump(GeckoAutomationFacadeBase):
    """Pumps are similar to switches, but might have variable speeds too"""

    def __init__(self, facade, key, props, user_demand):
        """props is a tuple of (name, keypad_button, state_key, device_class)"""
        super().__init__(facade, props[0], key)
        self.ui_key = key
        self._state_sensor = GeckoSensor(
            facade, f"{props[0]} State", self._spa.accessors[props[2]]
        )
        self._state_sensor.watch(self._on_change)
        self._keypad_button = props[1]
        self.device_class = props[3]
        self._user_demand = user_demand

    @property
    def modes(self):
        return self._user_demand["options"]

    @property
    def mode(self):
        return self._state_sensor.state

    def set_mode(self, mode):
        try:
            logger.debug("%s set mode %s", self.name, mode)
            self.facade.spa.accessors[self._user_demand["demand"]].value = mode
        except Exception:  # pylint: disable=broad-except
            logger.exception(
                "Exception handling setting %s=%s", self._user_demand["demand"], mode
            )

    async def async_set_mode(self, mode):
        try:
            logger.debug("%s async set mode %s", self.name, mode)
            await self.facade.spa.accessors[
                self._user_demand["demand"]
            ].async_set_value(mode)
        except Exception:  # pylint: disable=broad-except
            logger.exception(
                "Exception handling setting %s=%s", self._user_demand["demand"], mode
            )

    def __str__(self):
        return f"{self.name}: {self._state_sensor.state}"

    @property
    def monitor(self):
        return f"{self.ui_key}: {self._state_sensor.state}"



""" Facade to hide implementation details """

import logging
import threading

from .blower import GeckoBlower
from ..const import GeckoConstants
from .heater import GeckoWaterHeater
from .keypad import GeckoKeypad
from .light import GeckoLight
from .pump import GeckoPump
from .switch import GeckoSwitch
from .sensors import GeckoSensor, GeckoBinarySensor
from .watercare import GeckoWaterCare
from ..driver import Observable

logger = logging.getLogger(__name__)


class GeckoFacade(Observable):
    """Facade to abstract the Gecko implementation details and present an interface suitable
    for consumption by automation systems, e.g. Home Assistant. This class and all the
    output and state objects maintain their state locally so there should be no need to
    poll"""

    def __init__(self, spa):
        super().__init__()
        self._spa = spa
        self._sensors = []
        self._binary_sensors = []
        self._water_heater = None
        self._water_care = None
        self._keypad = None
        self._ecomode = None
        self._update_thread = threading.Thread(
            target=self._update_thread_func, daemon=True
        )
        self._update_thread.start()
        self._facade_ready = False
        self._spa.on_connected = self._on_connected

    def __enter__(self):
        return self

    def __exit__(self, *args):
        if self._spa:
            self._spa.complete()
            self._spa = None
        if self._update_thread:
            self._update_thread.join()

    def _on_connected(self, spa):
        logger.debug("Facade knows spa is connected")
        self._water_heater = GeckoWaterHeater(self)
        self._water_care = GeckoWaterCare(self)
        self._keypad = GeckoKeypad(self)
        self.scan_outputs()
        # Install change notifications
        for device in self.all_automation_devices:
            device.watch(self._on_change)
        logger.debug("Facade is now ready")
        self._facade_ready = True

    def complete(self):
        """Finish using this facade if not used in a `with` statement"""
        self.__exit__()

    @property
    def is_connected(self):
        try:
            if not self._spa.is_connected:
                return False
            return self._facade_ready
        except Exception as e:
            logger.exception(e)
            return False

    @property
    def is_in_error(self):
        return self._spa.is_in_error

    def wait(self, timeout):
        self.spa.wait(timeout)
        if self.is_in_error:
            raise Exception("Facade in error from previous exception")

    def scan_outputs(self):
        """Scan the spa outputs to decide what user options are available"""
        logger.debug("All outputs are %s", self._spa.struct.all_outputs)
        # Workout what (if anything) the outputs are connected to
        all_output_connections = {
            output: self._spa.accessors[output].value
            for output in self._spa.struct.all_outputs
        }
        logger.debug("Output connections are %s", all_output_connections)
        # Reduce the dictionary to those that are not set to NA (Not Applicable)
        actual_connections = {
            tag: val for (tag, val) in all_output_connections.items() if val != "NA"
        }
        logger.debug("Actual connections are %s", actual_connections)

        logger.debug("All devices are %s", self._spa.struct.all_devices)
        # If any of the actual connection values starts with any of the devices,
        # then the device is present
        actual_devices = set(
            [
                device
                for device in self._spa.struct.all_devices
                for val in actual_connections.values()
                if val.startswith(device)
            ]
        )
        logger.debug("Actual devices are %s", actual_devices)

        logger.debug("Possible user demands are %s", self._spa.struct.user_demands)
        # Actual user devices are those where the actual device has a corresponding
        # user demand
        self.actual_user_devices = [
            {
                "device": device,
                "user_demand": {
                    "demand": self._spa.accessors[f"{ud}"].tag,
                    "options": self._spa.accessors[f"{ud}"].items,
                },
            }
            for device in actual_devices
            for ud in self._spa.struct.user_demands
            if f"Ud{device}".upper() == ud.upper()
        ]
        logger.debug("Actual user devices are %s", self.actual_user_devices)

        # These keys can be used to determine the actual state ...
        # Key       Desc        Outputs         Keypad      Direct Drive
        # P1 ...    Pump 1      Out1A->P1H      1           <Doesn't work as expected>
        # Pn ...    Pump n      Out?A/B->PnH/L  n                     ""

        # Fix for issue#1 https://github.com/gazoodle/geckolib/issues/1
        # self.actual_user_devices.append("Waterfall")
        # Remove unknown device classes
        self.actual_user_devices = [
            handled_device
            for handled_device in self.actual_user_devices
            if handled_device["device"] in GeckoConstants.DEVICES
        ]
        logger.debug("Handled user devices are %s", self.actual_user_devices)

        self._pumps = [
            GeckoPump(
                self,
                device["device"],
                GeckoConstants.DEVICES[device["device"]],
                device["user_demand"],
            )
            for device in self.actual_user_devices
            if GeckoConstants.DEVICES[device["device"]][3]
            == GeckoConstants.DEVICE_CLASS_PUMP
        ]

        self._blowers = [
            GeckoBlower(
                self, device["device"], GeckoConstants.DEVICES[device["device"]]
            )
            for device in self.actual_user_devices
            if GeckoConstants.DEVICES[device["device"]][3]
            == GeckoConstants.DEVICE_CLASS_BLOWER
        ]

        self._lights = [
            GeckoLight(self, device["device"], GeckoConstants.DEVICES[device["device"]])
            for device in self.actual_user_devices
            if GeckoConstants.DEVICES[device["device"]][3]
            == GeckoConstants.DEVICE_CLASS_LIGHT
        ]

        self._sensors = [
            GeckoSensor(self, sensor[0], self._spa.accessors[sensor[1]])
            for sensor in GeckoConstants.SENSORS
            if sensor[1] in self._spa.accessors
        ]

        self._binary_sensors = [
            GeckoBinarySensor(
                self, binary_sensor[0], self._spa.accessors[binary_sensor[1]]
            )
            for binary_sensor in GeckoConstants.BINARY_SENSORS
            if binary_sensor[1] in self._spa.accessors
        ]

        if GeckoConstants.KEY_ECON_ACTIVE in self._spa.accessors:
            self._ecomode = GeckoSwitch(
                self,
                GeckoConstants.KEY_ECON_ACTIVE,
                (
                    GeckoConstants.ECON_ACTIVE_DESCRIPTION,
                    GeckoConstants.KEYPAD_ECOMODE,
                    GeckoConstants.KEY_ECON_ACTIVE,
                    GeckoConstants.DEVICE_CLASS_SWITCH,
                ),
            )

    @property
    def unique_id(self):
        """A unique id for the facade"""
        return f"{self.identifier.replace(':', '')}"

    @property
    def name(self):
        """Get the spa name"""
        return self._spa.descriptor.name

    @property
    def identifier(self):
        """Get the spa identifier"""
        return self._spa.descriptor.identifier_as_string

    @property
    def spa(self):
        """Get the spa implementation class"""
        return self._spa

    @property
    def water_heater(self):
        """Get the water heater handler"""
        return self._water_heater

    @property
    def water_care(self):
        """Get the water care handler"""
        return self._water_care

    @property
    def keypad(self):
        """Get the keypad handler"""
        return self._keypad

    @property
    def pumps(self) -> [GeckoPump]:
        """Get the pumps list"""
        return self._pumps

    @property
    def blowers(self):
        """Get the blowers list"""
        return self._blowers

    @property
    def lights(self):
        """Get the lights list"""
        return self._lights

    @property
    def sensors(self):
        """Get the sensor list"""
        return self._sensors

    @property
    def binary_sensors(self):
        """Get the binary sensor list"""
        return self._binary_sensors

    @property
    def eco_mode(self):
        """Get the Eco Mode switch"""
        return self._ecomode

    @property
    def all_user_devices(self):
        """Get all the user controllable devices as a list"""
        return self._pumps + self._blowers + self._lights

    @property
    def all_automation_devices(self):
        """Get all the automation devices as a list"""
        return (
            self.all_user_devices
            + self.sensors
            + self.binary_sensors
            + [self.water_heater, self.water_care, self.keypad, self.eco_mode]
        )

    def get_device(self, key):
        """Get an automation device from the key"""
        for device in self.all_automation_devices:
            if device.key == key:
                return device
        return None

    @property
    def devices(self):
        """Get a list of automation device keys. Keys can be passed to get_device
        to find the specific device"""
        return [device.key for device in self.all_automation_devices]

    @property
    def reminders(self):
        """Get the reminders list"""
        return []

    def _update_thread_func(self):
        while self.spa.isopen:
            if self._water_care is None:
                self.spa.wait(0.1)
                continue
            self.water_care.update()
            if self._water_care.active_mode is None:
                self.spa.wait(0.1)
                continue
            self.spa.wait(GeckoConstants.FACADE_UPDATE_FREQUENCY_IN_SECONDS)

        logger.info("Facade update thread finished")



#!/usr/bin/python3
"""
    GeckoConfigStruct - A class to manage the ConfigStruct for 'InXE v50'
"""

from . import (
    GeckoByteStructAccessor,
    GeckoWordStructAccessor,
    GeckoTimeStructAccessor,
    GeckoBoolStructAccessor,
    GeckoEnumStructAccessor,
    GeckoTempStructAccessor,
)

# Constants for this class
ACCPQI = "".join(chr(c) for c in [65, 76, 87, 65, 89, 83, 95, 79, 78])
AHEOCT = "".join(chr(c) for c in [79, 117, 116, 53, 67, 117, 114])
AJVDQL = 50
AKQXPI = 14
AMJMAO = "".join(chr(c) for c in [67, 69])
AOAWBS = "".join(
    chr(c) for c in [73, 110, 112, 117, 116, 67, 117, 114, 114, 101, 110, 116]
)
AONPYY = 85
ASSAKQ = "".join(chr(c) for c in [79, 117, 116, 50])
AWBSIR = "".join(chr(c) for c in [73, 110, 112, 117, 116, 77, 101, 110, 117])
BFEGZU = "".join(chr(c) for c in [79, 117, 116, 49, 49, 67, 117, 114])
BIAMJM = 51
BLKXSJ = "".join(chr(c) for c in [79, 51, 85, 115, 97, 103, 101])
BMJVHF = "".join(chr(c) for c in [79, 117, 116, 49])
BQFYLJ = "".join(chr(c) for c in [70, 105, 108, 116, 68, 117, 114])
BQSNQL = "".join(chr(c) for c in [66, 108, 111, 119, 101, 114, 79, 110, 73, 50, 67])
BSIRYX = "".join(chr(c) for c in [68, 117, 97, 108, 80, 97, 99, 107])
BSKSOK = 19
BWJYKL = "".join(chr(c) for c in [70])
BXYBQS = "".join(
    chr(c) for c in [77, 117, 108, 116, 105, 75, 101, 121, 79, 112, 116, 105, 111, 110]
)
CBFEGZ = 46
CPQIPO = "".join(
    chr(c) for c in [79, 84, 65, 99, 116, 83, 101, 116, 112, 111, 105, 110, 116, 71]
)
CQBMJV = 0
CTHBSK = "".join(chr(c) for c in [79, 117, 116, 54])
CVYYPI = "".join(chr(c) for c in [80, 52, 72])
CWAONP = 56
CXQIEF = 17
ECVYYP = "".join(chr(c) for c in [80, 51, 76])
EFXQGL = 36
EGZUQE = "".join(chr(c) for c in [79, 117, 116, 49, 50, 67, 117, 114])
EJNIBX = "".join(
    chr(c) for c in [79, 102, 102, 79, 110, 67, 117, 115, 116, 111, 109, 75, 101, 121]
)
EKCWAO = 55
EKVKZI = 34
EOCTHB = "".join(chr(c) for c in [79, 117, 116, 72, 116, 82, 67, 117, 114])
EXLSXU = 50
FEFJTA = "".join(chr(c) for c in [70, 105, 108, 116, 80, 49])
FEGZUQ = 47
FJBIAM = 81
FJTACC = "".join(chr(c) for c in [67, 112, 85, 115, 97, 103, 101])
FTHECV = "".join(chr(c) for c in [80, 50, 72])
FTSIFJ = 74
FXQGLR = "".join(chr(c) for c in [79, 117, 116, 50, 67, 117, 114])
FYLJUI = "".join(chr(c) for c in [69, 99, 111, 110, 83, 116, 97, 114, 116])
GLRAHE = 38
GQPLSP = 35
GYOUSP = "".join(
    chr(c) for c in [79, 51, 83, 117, 115, 112, 101, 110, 100, 84, 105, 109, 101]
)
GZUQEX = 48
HBSKSO = "".join(chr(c) for c in [79, 117, 116, 55])
HECVYY = "".join(chr(c) for c in [80, 51, 72])
HEOCTH = 40
HFTHEC = "".join(chr(c) for c in [80, 49, 76])
HUOJRJ = "".join(chr(c) for c in [79, 117, 116, 49, 49])
HXEKVK = 79
IAMJMA = "".join(chr(c) for c in [85, 76])
IBXYBQ = 3
ICXQIE = "".join(chr(c) for c in [79, 117, 116, 72, 116, 114])
IEFXQG = "".join(chr(c) for c in [79, 117, 116, 49, 67, 117, 114])
IFJBIA = "".join(
    chr(c) for c in [78, 111, 72, 101, 97, 116, 80, 101, 114, 105, 111, 100]
)
IKFWRK = 75
ILXWAJ = 68
INEJNI = 76
IPIVLA = "".join(chr(c) for c in [79, 51])
IPOUYN = 59
IRYXBQ = "".join(chr(c) for c in [70, 105, 108, 116, 70, 114, 101, 113])
IUSOOQ = "".join(chr(c) for c in [68, 105, 114, 101, 99, 116, 50])
IUXFEF = 32
IVLASS = "".join(chr(c) for c in [])
JBIAMJ = "".join(chr(c) for c in [85, 76, 95, 67, 69])
JHIUSO = 25
JIGYOU = "".join(chr(c) for c in [84, 111, 103, 103, 108, 101])
JMAOAW = "".join(chr(c) for c in [78, 98, 80, 104, 97, 115, 101, 115])
JMCBFE = 45
JNIBXY = 1
JRJHIU = 24
JTACCP = 27
JUIKFW = 10
JUTYEK = 84
JVHFTH = "".join(chr(c) for c in [78, 65])
JWMNZM = "".join(chr(c) for c in [79, 51, 80, 117, 109, 112])
JYMOUN = "".join(
    chr(c)
    for c in [70, 105, 108, 116, 83, 117, 115, 112, 101, 110, 100, 84, 105, 109, 101]
)
KCWAON = "".join(chr(c) for c in [76, 49, 50, 48, 84, 105, 109, 101, 79, 117, 116])
KFWRKI = "".join(chr(c) for c in [65, 118, 97, 105, 108, 97, 98, 108, 101])
KINEJN = "".join(
    chr(c)
    for c in [
        69,
        99,
        111,
        110,
        67,
        111,
        110,
        116,
        114,
        111,
        108,
        97,
        98,
        108,
        101,
        77,
        97,
        110,
        117,
        97,
        108,
        108,
        121,
    ]
)
KLGQPL = 31
KPHUOJ = "".join(chr(c) for c in [79, 117, 116, 49, 48])
KQXPIC = "".join(chr(c) for c in [79, 117, 116, 52])
KSOKPH = 20
KVKZIL = "".join(chr(c) for c in [65, 109, 80, 109])
KXSJWM = "".join(chr(c) for c in [70, 105, 108, 116, 101, 114])
LGQPLS = "".join(
    chr(c) for c in [67, 111, 111, 108, 100, 111, 119, 110, 84, 105, 109, 101]
)
LIUXFE = "".join(
    chr(c) for c in [70, 105, 108, 116, 73, 110, 116, 101, 114, 102, 97, 99, 101]
)
LJUIKF = "".join(chr(c) for c in [69, 99, 111, 110, 68, 117, 114])
LKXSJW = 28
LNMHXE = "".join(chr(c) for c in [83, 108, 97, 118, 101])
LRAHEO = "".join(chr(c) for c in [79, 117, 116, 52, 67, 117, 114])
LSPFTS = "".join(
    chr(c) for c in [77, 97, 120, 83, 101, 116, 112, 111, 105, 110, 116, 71]
)
LSXUJU = 83
MAOAWB = 52
MCBFEG = "".join(chr(c) for c in [79, 117, 116, 49, 48, 67, 117, 114])
MHXEKV = "".join(chr(c) for c in [83, 108, 97, 118, 101, 67, 111, 110, 102, 105, 103])
MJIGYO = "".join(chr(c) for c in [83, 116, 97, 110, 100, 97, 114, 100])
MJVHFT = 12
MOUNBL = "".join(chr(c) for c in [68, 114, 97, 105, 110, 77, 111, 100, 101])
NEJNIB = "".join(
    chr(c)
    for c in [83, 111, 97, 107, 79, 110, 67, 117, 115, 116, 111, 109, 75, 101, 121]
)
NIBXYB = "".join(
    chr(c)
    for c in [
        67,
        108,
        101,
        97,
        110,
        117,
        112,
        79,
        110,
        67,
        117,
        115,
        116,
        111,
        109,
        75,
        101,
        121,
    ]
)
NPYYLI = "".join(chr(c) for c in [79, 119, 110])
NQJYMO = "".join(
    chr(c)
    for c in [
        70,
        105,
        108,
        116,
        79,
        110,
        84,
        105,
        109,
        101,
        68,
        117,
        114,
        105,
        110,
        103,
        79,
        84,
    ]
)
NQLNMH = 77
NRSJMC = "".join(chr(c) for c in [79, 117, 116, 56, 67, 117, 114])
NZMJIG = "".join(chr(c) for c in [79, 51, 84, 121, 112, 101])
OAWBSI = 53
OCTHBS = 41
OJRJHI = "".join(chr(c) for c in [79, 117, 116, 49, 50])
OKPHUO = 21
ONPYYL = "".join(chr(c) for c in [83, 104, 97, 114, 101, 100])
OOQNRS = 42
OQNRSJ = "".join(chr(c) for c in [79, 117, 116, 55, 67, 117, 114])
OUNBLK = 82
OUSPBW = "".join(chr(c) for c in [83, 101, 116, 112, 111, 105, 110, 116, 71])
OUYNQJ = 60
PBWJYK = 33
PFTSIF = "".join(chr(c) for c in [69, 99, 111, 110, 84, 121, 112, 101])
PHUOJR = 22
PICXQI = 16
PIPIVL = "".join(chr(c) for c in [67, 80])
PIVLAS = "".join(chr(c) for c in [76, 49, 50, 48])
PLSPFT = 70
POUYNQ = "".join(
    chr(c)
    for c in [67, 112, 79, 110, 84, 105, 109, 101, 68, 117, 114, 105, 110, 103, 79, 84]
)
PQIPOU = 57
QBMJVH = "".join(chr(c) for c in [65, 76, 76])
QEXLSX = "".join(chr(c) for c in [68, 105, 114, 101, 99, 116, 50, 67, 117, 114])
QFYLJU = 6
QGLRAH = "".join(chr(c) for c in [79, 117, 116, 51, 67, 117, 114])
QIPOUY = "".join(chr(c) for c in [79, 84, 84, 114, 105, 103, 103, 101, 114, 71])
QJYMOU = 64
QLNMHX = "".join(chr(c) for c in [77, 97, 115, 116, 101, 114])
QNRSJM = 43
QPLSPF = "".join(
    chr(c) for c in [77, 105, 110, 83, 101, 116, 112, 111, 105, 110, 116, 71]
)
QXPICX = 15
RAHEOC = 39
RJHIUS = "".join(chr(c) for c in [68, 105, 114, 101, 99, 116])
RKINEJ = 86
RSJMCB = 44
RYXBQF = 3
SAKQXP = "".join(chr(c) for c in [79, 117, 116, 51])
SJMCBF = "".join(chr(c) for c in [79, 117, 116, 57, 67, 117, 114])
SKSOKP = "".join(chr(c) for c in [79, 117, 116, 56])
SNQLNM = "".join(chr(c) for c in [77, 97, 115, 116, 101, 114, 83, 108, 97, 118, 101])
SOKPHU = "".join(chr(c) for c in [79, 117, 116, 57])
SOOQNR = "".join(chr(c) for c in [79, 117, 116, 54, 67, 117, 114])
SPBWJY = "".join(chr(c) for c in [84, 101, 109, 112, 85, 110, 105, 116, 115])
SPFTSI = 72
SSAKQX = 13
SXUJUT = "".join(chr(c) for c in [76, 73])
TACCPQ = "".join(chr(c) for c in [83, 84, 65, 78, 68, 65, 82, 68])
THBSKS = 18
THECVY = "".join(chr(c) for c in [80, 50, 76])
TSIFJB = "".join(chr(c) for c in [78, 105, 103, 104, 116])
TYEKCW = 54
UIKFWR = "".join(
    chr(c)
    for c in [
        69,
        99,
        111,
        110,
        80,
        114,
        111,
        103,
        65,
        118,
        97,
        105,
        108,
        97,
        98,
        108,
        101,
    ]
)
UJUTYE = "".join(chr(c) for c in [76, 105, 103, 104, 116, 73, 110, 116, 115])
UNBLKX = "".join(chr(c) for c in [80, 49])
UOJRJH = 23
UQEXLS = 49
USOOQN = 26
USPBWJ = 1
UTYEKC = "".join(chr(c) for c in [80, 117, 109, 112, 84, 105, 109, 101, 79, 117, 116])
UXFEFJ = "".join(chr(c) for c in [80, 117, 114, 103, 101, 79, 110, 108, 121])
UYNQJY = "".join(
    chr(c)
    for c in [
        67,
        112,
        79,
        102,
        102,
        84,
        105,
        109,
        101,
        68,
        117,
        114,
        105,
        110,
        103,
        79,
        84,
    ]
)
VHFTHE = "".join(chr(c) for c in [80, 49, 72])
VKZILX = "".join(chr(c) for c in [50, 52, 104])
VLASSA = "".join(chr(c) for c in [70, 117, 108, 108, 79, 110])
VYYPIP = "".join(chr(c) for c in [80, 52, 76])
WAONPY = "".join(chr(c) for c in [76, 49, 50, 48, 84, 105, 109, 101, 114])
WBSIRY = 78
WJYKLG = "".join(chr(c) for c in [67])
WMNZMJ = 29
WRKINE = "".join(chr(c) for c in [85, 68, 80, 114, 111, 103, 69, 99, 111, 110])
XBQFYL = 4
XEKVKZ = "".join(chr(c) for c in [84, 105, 109, 101, 70, 111, 114, 109, 97, 116])
XFEFJT = "".join(chr(c) for c in [70, 105, 108, 116, 67, 80])
XLSXUJ = "".join(chr(c) for c in [79, 117, 116, 76, 105])
XPICXQ = "".join(chr(c) for c in [79, 117, 116, 53])
XQGLRA = 37
XQIEFX = "".join(chr(c) for c in [72, 84, 82])
XSJWMN = "".join(chr(c) for c in [65, 108, 119, 97, 121, 115])
XYBQSN = 80
YBQSNQ = "".join(
    chr(c) for c in [78, 111, 66, 108, 111, 119, 101, 114, 79, 110, 73, 50, 67]
)
YEKCWA = "".join(
    chr(c) for c in [76, 105, 103, 104, 116, 84, 105, 109, 101, 79, 117, 116]
)
YKLGQP = "".join(chr(c) for c in [72, 101, 97, 116, 101, 114, 80, 117, 109, 112])
YLIUXF = 2
YLJUIK = 8
YMOUNB = 66
YNQJYM = 62
YOUSPB = 67
YPIPIV = "".join(chr(c) for c in [66, 76, 79])
YXBQFY = "".join(chr(c) for c in [70, 105, 108, 116, 83, 116, 97, 114, 116])
YYLIUX = 0
YYPIPI = "".join(chr(c) for c in [80, 53])
ZCQBMJ = "".join(
    chr(c) for c in [67, 111, 110, 102, 105, 103, 78, 117, 109, 98, 101, 114]
)
ZILXWA = "".join(
    chr(c)
    for c in [65, 109, 98, 105, 97, 110, 116, 79, 72, 84, 114, 105, 103, 65, 68, 67]
)
ZMJIGY = 30
ZUQEXL = "".join(chr(c) for c in [68, 105, 114, 101, 99, 116, 67, 117, 114])
CCPQIP = [TACCPQ, ACCPQI]
EFJTAC = [UXFEFJ, XFEFJT, FEFJTA]
FWRKIN = [JVHFTH, KFWRKI]
HIUSOO = [
    JVHFTH,
    IVLASS,
    IVLASS,
    IVLASS,
    IVLASS,
    IVLASS,
    IVLASS,
    IVLASS,
    IVLASS,
    IVLASS,
    IVLASS,
    PIPIVL,
]
IGYOUS = [MJIGYO, JIGYOU]
JYKLGQ = [BWJYKL, WJYKLG]
KZILXW = [JVHFTH, KVKZIL, VKZILX]
LASSAK = [
    JVHFTH,
    VHFTHE,
    HFTHEC,
    FTHECV,
    THECVY,
    HECVYY,
    ECVYYP,
    CVYYPI,
    VYYPIP,
    YYPIPI,
    YPIPIV,
    PIPIVL,
    IPIVLA,
    PIVLAS,
    IVLASS,
    IVLASS,
    IVLASS,
    IVLASS,
    IVLASS,
    VLASSA,
]
LXWAJV = [
    BMJVHF,
    ASSAKQ,
    SAKQXP,
    KQXPIC,
    XPICXQ,
    ICXQIE,
    CTHBSK,
    HBSKSO,
    SKSOKP,
    SOKPHU,
    KPHUOJ,
    HUOJRJ,
    OJRJHI,
    RJHIUS,
    IUSOOQ,
    XLSXUJ,
]
MJMAOA = [IAMJMA, AMJMAO]
MNZMJI = [PIPIVL, UNBLKX]
NBLKXS = [JVHFTH, UNBLKX, PIPIVL]
NMHXEK = [IVLASS, QLNMHX, LNMHXE]
PYYLIU = [ONPYYL, NPYYLI]
QIEFXQ = [
    JVHFTH,
    IVLASS,
    IVLASS,
    IVLASS,
    IVLASS,
    IVLASS,
    IVLASS,
    IVLASS,
    IVLASS,
    IVLASS,
    IVLASS,
    IVLASS,
    IVLASS,
    IVLASS,
    XQIEFX,
]
QSNQLN = [YBQSNQ, BQSNQL]
SIFJBI = [MJIGYO, TSIFJB]
SIRYXB = [MJIGYO, BSIRYX]
SJWMNZ = [KXSJWM, XSJWMN]
WAJVDQ = []
XUJUTY = [
    IVLASS,
    IVLASS,
    IVLASS,
    IVLASS,
    IVLASS,
    IVLASS,
    IVLASS,
    IVLASS,
    IVLASS,
    IVLASS,
    IVLASS,
    IVLASS,
    IVLASS,
    IVLASS,
    IVLASS,
    SXUJUT,
]
XWAJVD = [SXUJUT]


class GeckoConfigStruct:
    def __init__(self, struct_):
        self.struct = struct_

    @property
    def version(self):
        return AJVDQL

    @property
    def output_keys(self):
        return LXWAJV

    @property
    def accessors(self):
        return {
            ZCQBMJ: GeckoByteStructAccessor(self.struct, ZCQBMJ, CQBMJV, QBMJVH),
            BMJVHF: GeckoEnumStructAccessor(
                self.struct, BMJVHF, MJVHFT, None, LASSAK, None, None, QBMJVH
            ),
            ASSAKQ: GeckoEnumStructAccessor(
                self.struct, ASSAKQ, SSAKQX, None, LASSAK, None, None, QBMJVH
            ),
            SAKQXP: GeckoEnumStructAccessor(
                self.struct, SAKQXP, AKQXPI, None, LASSAK, None, None, QBMJVH
            ),
            KQXPIC: GeckoEnumStructAccessor(
                self.struct, KQXPIC, QXPICX, None, LASSAK, None, None, QBMJVH
            ),
            XPICXQ: GeckoEnumStructAccessor(
                self.struct, XPICXQ, PICXQI, None, LASSAK, None, None, QBMJVH
            ),
            ICXQIE: GeckoEnumStructAccessor(
                self.struct, ICXQIE, CXQIEF, None, QIEFXQ, None, None, QBMJVH
            ),
            IEFXQG: GeckoByteStructAccessor(self.struct, IEFXQG, EFXQGL, QBMJVH),
            FXQGLR: GeckoByteStructAccessor(self.struct, FXQGLR, XQGLRA, QBMJVH),
            QGLRAH: GeckoByteStructAccessor(self.struct, QGLRAH, GLRAHE, QBMJVH),
            LRAHEO: GeckoByteStructAccessor(self.struct, LRAHEO, RAHEOC, QBMJVH),
            AHEOCT: GeckoByteStructAccessor(self.struct, AHEOCT, HEOCTH, QBMJVH),
            EOCTHB: GeckoByteStructAccessor(self.struct, EOCTHB, OCTHBS, QBMJVH),
            CTHBSK: GeckoEnumStructAccessor(
                self.struct, CTHBSK, THBSKS, None, LASSAK, None, None, QBMJVH
            ),
            HBSKSO: GeckoEnumStructAccessor(
                self.struct, HBSKSO, BSKSOK, None, LASSAK, None, None, QBMJVH
            ),
            SKSOKP: GeckoEnumStructAccessor(
                self.struct, SKSOKP, KSOKPH, None, LASSAK, None, None, QBMJVH
            ),
            SOKPHU: GeckoEnumStructAccessor(
                self.struct, SOKPHU, OKPHUO, None, LASSAK, None, None, QBMJVH
            ),
            KPHUOJ: GeckoEnumStructAccessor(
                self.struct, KPHUOJ, PHUOJR, None, LASSAK, None, None, QBMJVH
            ),
            HUOJRJ: GeckoEnumStructAccessor(
                self.struct, HUOJRJ, UOJRJH, None, LASSAK, None, None, QBMJVH
            ),
            OJRJHI: GeckoEnumStructAccessor(
                self.struct, OJRJHI, JRJHIU, None, LASSAK, None, None, QBMJVH
            ),
            RJHIUS: GeckoEnumStructAccessor(
                self.struct, RJHIUS, JHIUSO, None, HIUSOO, None, None, QBMJVH
            ),
            IUSOOQ: GeckoEnumStructAccessor(
                self.struct, IUSOOQ, USOOQN, None, HIUSOO, None, None, QBMJVH
            ),
            SOOQNR: GeckoByteStructAccessor(self.struct, SOOQNR, OOQNRS, QBMJVH),
            OQNRSJ: GeckoByteStructAccessor(self.struct, OQNRSJ, QNRSJM, QBMJVH),
            NRSJMC: GeckoByteStructAccessor(self.struct, NRSJMC, RSJMCB, QBMJVH),
            SJMCBF: GeckoByteStructAccessor(self.struct, SJMCBF, JMCBFE, QBMJVH),
            MCBFEG: GeckoByteStructAccessor(self.struct, MCBFEG, CBFEGZ, QBMJVH),
            BFEGZU: GeckoByteStructAccessor(self.struct, BFEGZU, FEGZUQ, QBMJVH),
            EGZUQE: GeckoByteStructAccessor(self.struct, EGZUQE, GZUQEX, QBMJVH),
            ZUQEXL: GeckoByteStructAccessor(self.struct, ZUQEXL, UQEXLS, QBMJVH),
            QEXLSX: GeckoByteStructAccessor(self.struct, QEXLSX, EXLSXU, QBMJVH),
            XLSXUJ: GeckoEnumStructAccessor(
                self.struct, XLSXUJ, LSXUJU, None, XUJUTY, None, None, None
            ),
            UJUTYE: GeckoByteStructAccessor(self.struct, UJUTYE, JUTYEK, None),
            UTYEKC: GeckoByteStructAccessor(self.struct, UTYEKC, TYEKCW, QBMJVH),
            YEKCWA: GeckoByteStructAccessor(self.struct, YEKCWA, EKCWAO, QBMJVH),
            KCWAON: GeckoByteStructAccessor(self.struct, KCWAON, CWAONP, QBMJVH),
            WAONPY: GeckoEnumStructAccessor(
                self.struct, WAONPY, AONPYY, YYLIUX, PYYLIU, None, YLIUXF, QBMJVH
            ),
            LIUXFE: GeckoEnumStructAccessor(
                self.struct, LIUXFE, IUXFEF, None, EFJTAC, None, None, QBMJVH
            ),
            FJTACC: GeckoEnumStructAccessor(
                self.struct, FJTACC, JTACCP, None, CCPQIP, None, None, QBMJVH
            ),
            CPQIPO: GeckoTempStructAccessor(self.struct, CPQIPO, PQIPOU, QBMJVH),
            QIPOUY: GeckoByteStructAccessor(self.struct, QIPOUY, IPOUYN, QBMJVH),
            POUYNQ: GeckoWordStructAccessor(self.struct, POUYNQ, OUYNQJ, QBMJVH),
            UYNQJY: GeckoWordStructAccessor(self.struct, UYNQJY, YNQJYM, QBMJVH),
            NQJYMO: GeckoWordStructAccessor(self.struct, NQJYMO, QJYMOU, QBMJVH),
            JYMOUN: GeckoByteStructAccessor(self.struct, JYMOUN, YMOUNB, QBMJVH),
            MOUNBL: GeckoEnumStructAccessor(
                self.struct, MOUNBL, OUNBLK, None, NBLKXS, None, None, QBMJVH
            ),
            BLKXSJ: GeckoEnumStructAccessor(
                self.struct, BLKXSJ, LKXSJW, None, SJWMNZ, None, None, QBMJVH
            ),
            JWMNZM: GeckoEnumStructAccessor(
                self.struct, JWMNZM, WMNZMJ, None, MNZMJI, None, None, QBMJVH
            ),
            NZMJIG: GeckoEnumStructAccessor(
                self.struct, NZMJIG, ZMJIGY, None, IGYOUS, None, None, QBMJVH
            ),
            GYOUSP: GeckoByteStructAccessor(self.struct, GYOUSP, YOUSPB, QBMJVH),
            OUSPBW: GeckoTempStructAccessor(self.struct, OUSPBW, USPBWJ, QBMJVH),
            SPBWJY: GeckoEnumStructAccessor(
                self.struct, SPBWJY, PBWJYK, None, JYKLGQ, None, None, QBMJVH
            ),
            YKLGQP: GeckoEnumStructAccessor(
                self.struct, YKLGQP, KLGQPL, None, MNZMJI, None, None, QBMJVH
            ),
            LGQPLS: GeckoByteStructAccessor(self.struct, LGQPLS, GQPLSP, QBMJVH),
            QPLSPF: GeckoTempStructAccessor(self.struct, QPLSPF, PLSPFT, QBMJVH),
            LSPFTS: GeckoTempStructAccessor(self.struct, LSPFTS, SPFTSI, QBMJVH),
            PFTSIF: GeckoEnumStructAccessor(
                self.struct, PFTSIF, FTSIFJ, None, SIFJBI, None, None, QBMJVH
            ),
            IFJBIA: GeckoByteStructAccessor(self.struct, IFJBIA, FJBIAM, QBMJVH),
            JBIAMJ: GeckoEnumStructAccessor(
                self.struct, JBIAMJ, BIAMJM, None, MJMAOA, None, None, QBMJVH
            ),
            JMAOAW: GeckoByteStructAccessor(self.struct, JMAOAW, MAOAWB, QBMJVH),
            AOAWBS: GeckoByteStructAccessor(self.struct, AOAWBS, OAWBSI, QBMJVH),
            AWBSIR: GeckoEnumStructAccessor(
                self.struct, AWBSIR, WBSIRY, None, SIRYXB, None, None, QBMJVH
            ),
            IRYXBQ: GeckoByteStructAccessor(self.struct, IRYXBQ, RYXBQF, QBMJVH),
            YXBQFY: GeckoTimeStructAccessor(self.struct, YXBQFY, XBQFYL, QBMJVH),
            BQFYLJ: GeckoTimeStructAccessor(self.struct, BQFYLJ, QFYLJU, QBMJVH),
            FYLJUI: GeckoTimeStructAccessor(self.struct, FYLJUI, YLJUIK, QBMJVH),
            LJUIKF: GeckoTimeStructAccessor(self.struct, LJUIKF, JUIKFW, QBMJVH),
            UIKFWR: GeckoEnumStructAccessor(
                self.struct, UIKFWR, IKFWRK, None, FWRKIN, None, None, QBMJVH
            ),
            WRKINE: GeckoBoolStructAccessor(
                self.struct, WRKINE, RKINEJ, YYLIUX, QBMJVH
            ),
            KINEJN: GeckoBoolStructAccessor(
                self.struct, KINEJN, INEJNI, YLIUXF, QBMJVH
            ),
            NEJNIB: GeckoBoolStructAccessor(
                self.struct, NEJNIB, INEJNI, YYLIUX, QBMJVH
            ),
            EJNIBX: GeckoBoolStructAccessor(
                self.struct, EJNIBX, INEJNI, JNIBXY, QBMJVH
            ),
            NIBXYB: GeckoBoolStructAccessor(
                self.struct, NIBXYB, INEJNI, IBXYBQ, QBMJVH
            ),
            BXYBQS: GeckoEnumStructAccessor(
                self.struct, BXYBQS, XYBQSN, None, QSNQLN, None, None, QBMJVH
            ),
            SNQLNM: GeckoEnumStructAccessor(
                self.struct, SNQLNM, NQLNMH, None, NMHXEK, None, None, QBMJVH
            ),
            MHXEKV: GeckoByteStructAccessor(self.struct, MHXEKV, HXEKVK, QBMJVH),
            XEKVKZ: GeckoEnumStructAccessor(
                self.struct, XEKVKZ, EKVKZI, None, KZILXW, None, None, QBMJVH
            ),
            ZILXWA: GeckoWordStructAccessor(self.struct, ZILXWA, ILXWAJ, QBMJVH),
        }
